@@ -129,7 +129,7 @@ ide_application_actions_about (GSimpleAction *action,
 
   version = g_string_new (NULL);
 
-  if (g_str_has_prefix (IDE_BUILD_TYPE, "debug"))
+  if (!g_str_equal (IDE_BUILD_TYPE, "release"))
     g_string_append (version, IDE_BUILD_IDENTIFIER);
   else
     g_string_append (version, PACKAGE_VERSION);
@@ -141,7 +141,7 @@ ide_application_actions_about (GSimpleAction *action,
                          "artists", ide_application_credits_artists,
                          "authors", ide_application_credits_authors,
                          "comments", _("An IDE for GNOME"),
-                         "copyright", "Copyright © 2014–2017 Christian Hergert, et al.",
+                         "copyright", "© 2014–2018 Christian Hergert, et al.",
                          "documenters", ide_application_credits_documenters,
                          "license-type", GTK_LICENSE_GPL_3_0,
                          "logo-icon-name", "org.gnome.Builder",
@@ -295,6 +295,18 @@ ide_application_actions_load_workbench_view (IdeApplication *self,
   gtk_window_present (GTK_WINDOW (workbench));
 }
 
+static void
+ide_application_actions_clone (GSimpleAction *action,
+                               GVariant      *variant,
+                               gpointer       user_data)
+{
+  IdeApplication *self = user_data;
+
+  g_assert (IDE_IS_APPLICATION (self));
+
+  ide_application_actions_load_workbench_view (self, "IdeGitGenesisAddin", NULL);
+}
+
 static void
 ide_application_actions_new_project (GSimpleAction *action,
                                      GVariant      *variant,
@@ -413,6 +425,7 @@ ide_application_actions_load_flatpak (GSimpleAction *action,
 
 static const GActionEntry IdeApplicationActions[] = {
   { "about",        ide_application_actions_about },
+  { "clone",        ide_application_actions_clone },
   { "dayhack",      ide_application_actions_dayhack },
   { "nighthack",    ide_application_actions_nighthack },
   { "open-project", ide_application_actions_open_project },
