@@ -37,6 +37,7 @@
 #include "application/ide-application-tests.h"
 #include "application/ide-application-tool.h"
 #include "modelines/modeline-parser.h"
+#include "terminal/ide-terminal-private.h"
 #include "threading/ide-thread-pool.h"
 #include "util/ide-battery-monitor.h"
 #include "util/ide-flatpak.h"
@@ -527,9 +528,12 @@ ide_application_startup (GApplication *application)
 
   G_APPLICATION_CLASS (ide_application_parent_class)->startup (application);
 
-  if (self->mode == IDE_APPLICATION_MODE_PRIMARY)
+  if (self->mode == IDE_APPLICATION_MODE_PRIMARY ||
+      self->mode == IDE_APPLICATION_MODE_TOOL)
     ide_application_register_plugin_accessories (self);
 
+  _ide_guess_shell ();
+
   ide_application_load_addins (self);
 }
 
