@@ -33,9 +33,9 @@ G_DECLARE_DERIVABLE_TYPE (IdeBufferChangeMonitor, ide_buffer_change_monitor, IDE
 typedef enum
 {
   IDE_BUFFER_LINE_CHANGE_NONE    = 0,
-  IDE_BUFFER_LINE_CHANGE_ADDED   = 1,
-  IDE_BUFFER_LINE_CHANGE_CHANGED = 2,
-  IDE_BUFFER_LINE_CHANGE_DELETED = 3,
+  IDE_BUFFER_LINE_CHANGE_ADDED   = 1 << 0,
+  IDE_BUFFER_LINE_CHANGE_CHANGED = 1 << 1,
+  IDE_BUFFER_LINE_CHANGE_DELETED = 1 << 2,
 } IdeBufferLineChange;
 
 struct _IdeBufferChangeMonitorClass
@@ -49,14 +49,7 @@ struct _IdeBufferChangeMonitorClass
   void                (*reload)     (IdeBufferChangeMonitor *self);
 
   /*< private >*/
-  gpointer _reserved1;
-  gpointer _reserved2;
-  gpointer _reserved3;
-  gpointer _reserved4;
-  gpointer _reserved5;
-  gpointer _reserved6;
-  gpointer _reserved7;
-  gpointer _reserved8;
+  gpointer _reserved[8];
 };
 
 IDE_AVAILABLE_IN_ALL
