@@ -39,9 +39,10 @@
 #include "projects/ide-project-edit.h"
 #include "projects/ide-project-edit-private.h"
 #include "sourceview/ide-completion-words.h"
-#include "util/ide-doc-seq.h"
-#include "util/ide-progress.h"
 #include "vcs/ide-vcs.h"
+#include "util/ide-doc-seq.h"
+#include "util/ide-glib.h"
+#include "util/ide-progress.h"
 
 #define AUTO_SAVE_TIMEOUT_DEFAULT    60
 #define MAX_FILE_SIZE_BYTES_DEFAULT  (1024UL * 1024UL * 10UL)
@@ -1218,6 +1219,8 @@ ide_buffer_manager_save_file_async (IdeBufferManager     *self,
   IdeContext *context;
   SaveState *state;
 
+  IDE_ENTRY;
+
   if (progress)
     *progress = NULL;
 
@@ -1228,6 +1231,22 @@ ide_buffer_manager_save_file_async (IdeBufferManager     *self,
   g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_source_tag (task, ide_buffer_manager_save_file_async);
+
+  /* Short cirtcuit if there is nothing to do. */
+  if (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (buffer)) &&
+      !ide_buffer_get_changed_on_volume (buffer) &&
+      ide_file_equal (file, ide_buffer_get_file (buffer)))
+    {
+      if (progress != NULL)
+        {
+          *progress = ide_progress_new ();
+          ide_progress_set_fraction (*progress, 1.0);
+        }
+
+      g_task_return_boolean (task, TRUE);
+      IDE_GOTO (unmodified);
+    }
 
   context = ide_object_get_context (IDE_OBJECT (self));
   ide_context_hold_for_object (context, task);
@@ -1254,7 +1273,10 @@ ide_buffer_manager_save_file_async (IdeBufferManager     *self,
                                 ide_buffer_manager_save_file__load_settings_cb,
                                 g_object_ref (task));
 
-  unregister_auto_save (self, state->buffer);
+unmodified:
+  unregister_auto_save (self, buffer);
+
+  IDE_EXIT;
 }
 
 /**
@@ -1789,7 +1811,7 @@ unregister_auto_save (IdeBufferManager *self,
  *
  * Buffers are generally not added to the buffer list until they have been loaded.
  *
- * Returns: (transfer container) (element-type Ide.Buffer): a #GPtrArray of buffers.
+ * Returns: (transfer full) (element-type Ide.Buffer): a #GPtrArray of buffers.
  */
 GPtrArray *
 ide_buffer_manager_get_buffers (IdeBufferManager *self)
@@ -1809,7 +1831,7 @@ ide_buffer_manager_get_buffers (IdeBufferManager *self)
       g_ptr_array_add (ret, g_object_ref (buffer));
     }
 
-  return g_steal_pointer (&ret);
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 /**
@@ -2293,7 +2315,7 @@ ide_buffer_manager_apply_edits_buffer_loaded (GObject      *object,
 /**
  * ide_buffer_manager_apply_edits_async:
  * @self: An #IdeBufferManager
- * @edits: (transfer container) (element-type Ide.ProjectEdit): An #GPtrArray of #IdeProjectEdit
+ * @edits: (transfer full) (element-type Ide.ProjectEdit): An #GPtrArray of #IdeProjectEdit
  * @cancellable: (allow-none): a #GCancellable or %NULL
  * @callback: the callback to complete the request
  * @user_data: user data for @callback
@@ -2319,6 +2341,8 @@ ide_buffer_manager_apply_edits_async (IdeBufferManager    *self,
   g_return_if_fail (edits != NULL);
   g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+  IDE_PTR_ARRAY_SET_FREE_FUNC (edits, g_object_unref);
+
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, ide_buffer_manager_apply_edits_async);
 
