@@ -18,22 +18,12 @@
 
 #pragma once
 
-#include <glib.h>
-
-#include "ide-version-macros.h"
-
-#include "ide-types.h"
-
-#include "buildconfig/ide-buildconfig-configuration.h"
+#include "ide-object.h"
 
 G_BEGIN_DECLS
 
 #define IDE_TYPE_BUILDCONFIG_CONFIGURATION_PROVIDER (ide_buildconfig_configuration_provider_get_type())
 
-G_DECLARE_FINAL_TYPE (IdeBuildconfigConfigurationProvider, ide_buildconfig_configuration_provider, IDE, BUILDCONFIG_CONFIGURATION_PROVIDER, GObject)
-
-IDE_AVAILABLE_IN_ALL
-void ide_buildconfig_configuration_provider_track_config (IdeBuildconfigConfigurationProvider *self,
-                                                          IdeBuildconfigConfiguration         *config);
+G_DECLARE_FINAL_TYPE (IdeBuildconfigConfigurationProvider, ide_buildconfig_configuration_provider, IDE, BUILDCONFIG_CONFIGURATION_PROVIDER, IdeObject)
 
 G_END_DECLS
