@@ -80,6 +80,8 @@ struct _IdeBuildManager
   guint             can_build : 1;
   guint             can_export : 1;
   guint             building : 1;
+  guint             needs_rediagnose : 1;
+  guint             has_configured : 1;
 };
 
 static void initable_iface_init              (GInitableIface  *iface);
@@ -546,6 +548,7 @@ initable_init (GInitable     *initable,
   IdeConfigurationManager *config_manager;
   IdeDeviceManager *device_manager;
   IdeContext *context;
+  IdeVcs *vcs;
 
   IDE_ENTRY;
 
@@ -555,6 +558,7 @@ initable_init (GInitable     *initable,
   context = ide_object_get_context (IDE_OBJECT (self));
   config_manager = ide_context_get_configuration_manager (context);
   device_manager = ide_context_get_device_manager (context);
+  vcs = ide_context_get_vcs (context);
 
   g_signal_connect_object (config_manager,
                            "invalidate",
@@ -568,6 +572,12 @@ initable_init (GInitable     *initable,
                            self,
                            G_CONNECT_SWAPPED);
 
+  g_signal_connect_object (vcs,
+                           "changed",
+                           G_CALLBACK (ide_build_manager_invalidate_pipeline),
+                           self,
+                           G_CONNECT_SWAPPED);
+
   ide_build_manager_invalidate_pipeline (self);
 
   IDE_RETURN (TRUE);
@@ -577,10 +587,28 @@ static void
 ide_build_manager_real_build_started (IdeBuildManager  *self,
                                       IdeBuildPipeline *pipeline)
 {
+  IdeBuildPhase phase;
+
   g_assert (IDE_IS_BUILD_MANAGER (self));
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
 
   ide_build_manager_start_timer (self);
+
+  /*
+   * When the build completes, we may want to update diagnostics for
+   * files that are open. But we only want to do this if we are reaching
+   * configure for the first time, or performing a real build.
+   */
+
+  phase = ide_build_pipeline_get_requested_phase (pipeline);
+  g_assert ((phase & IDE_BUILD_PHASE_MASK) == phase);
+
+  if (phase == IDE_BUILD_PHASE_BUILD ||
+      (phase == IDE_BUILD_PHASE_CONFIGURE && !self->has_configured))
+    {
+      self->needs_rediagnose = TRUE;
+      self->has_configured = TRUE;
+    }
 }
 
 static void
@@ -607,6 +635,13 @@ ide_build_manager_real_build_finished (IdeBuildManager  *self,
 
   ide_build_manager_stop_timer (self);
 
+  /*
+   * If this was not a full build (such as advancing to just the configure
+   * phase or so), then there is nothing more to do.
+   */
+  if (!self->needs_rediagnose)
+    return;
+
   /*
    * We had a successful build, so lets notify the build manager to reload
    * dianostics on loaded buffers so the user doesn't have to make a change
@@ -1187,7 +1222,6 @@ ide_build_manager_execute_cb (GObject      *object,
                               gpointer      user_data)
 {
   IdeBuildPipeline *pipeline = (IdeBuildPipeline *)object;
-  IdeBuildManager *self;
   g_autoptr(GTask) task = user_data;
   g_autoptr(GError) error = NULL;
 
@@ -1197,9 +1231,6 @@ ide_build_manager_execute_cb (GObject      *object,
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (G_IS_TASK (task));
 
-  self = g_task_get_source_object (task);
-  g_assert (IDE_IS_BUILD_MANAGER (self));
-
   if (!ide_build_pipeline_execute_finish (pipeline, result, &error))
     {
       ide_object_warning (pipeline, "%s", error->message);
@@ -1391,7 +1422,6 @@ ide_build_manager_clean_cb (GObject      *object,
   IdeBuildPipeline *pipeline = (IdeBuildPipeline *)object;
   g_autoptr(GTask) task = user_data;
   g_autoptr(GError) error = NULL;
-  IdeBuildManager *self;
 
   IDE_ENTRY;
 
@@ -1399,9 +1429,6 @@ ide_build_manager_clean_cb (GObject      *object,
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (G_IS_TASK (task));
 
-  self = g_task_get_source_object (task);
-  g_assert (IDE_IS_BUILD_MANAGER (self));
-
   if (!ide_build_pipeline_clean_finish (pipeline, result, &error))
     g_task_return_error (task, g_steal_pointer (&error));
   else
