@@ -73,6 +73,18 @@ ide_build_log_panel_log_observer (IdeBuildLogStream  stream,
   vte_terminal_feed (VTE_TERMINAL (self->terminal), "\r\n", -1);
 }
 
+static void
+ide_build_log_panel_notify_pty (IdeBuildLogPanel *self,
+                                GParamSpec       *pspec,
+                                IdeBuildPipeline *pipeline)
+{
+  g_assert (IDE_IS_BUILD_LOG_PANEL (self));
+  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+
+  vte_terminal_set_pty (VTE_TERMINAL (self->terminal),
+                        ide_build_pipeline_get_pty (pipeline));
+}
+
 void
 ide_build_log_panel_set_pipeline (IdeBuildLogPanel *self,
                                   IdeBuildPipeline *pipeline)
@@ -84,6 +96,9 @@ ide_build_log_panel_set_pipeline (IdeBuildLogPanel *self,
     {
       if (self->pipeline != NULL)
         {
+          g_signal_handlers_disconnect_by_func (self->pipeline,
+                                                G_CALLBACK (ide_build_log_panel_notify_pty),
+                                                self);
           ide_build_pipeline_remove_log_observer (self->pipeline, self->log_observer);
           self->log_observer = 0;
           g_clear_object (&self->pipeline);
@@ -100,7 +115,12 @@ ide_build_log_panel_set_pipeline (IdeBuildLogPanel *self,
                                                  NULL);
           vte_terminal_reset (VTE_TERMINAL (self->terminal), TRUE, TRUE);
           vte_terminal_set_pty (VTE_TERMINAL (self->terminal),
-                                _ide_build_pipeline_get_pty (pipeline));
+                                ide_build_pipeline_get_pty (pipeline));
+          g_signal_connect_object (pipeline,
+                                   "notify::pty",
+                                   G_CALLBACK (ide_build_log_panel_notify_pty),
+                                   self,
+                                   G_CONNECT_SWAPPED);
         }
     }
 }
@@ -278,6 +298,28 @@ ide_build_log_panel_save_in_file (GSimpleAction *action,
   IDE_EXIT;
 }
 
+static void
+terminal_size_allocate (IdeBuildLogPanel *self,
+                        GtkAllocation    *allocation,
+                        IdeTerminal      *terminal)
+{
+  VtePty *pty;
+  gint rows = 0;
+  gint columns = 0;
+
+  g_assert (IDE_IS_BUILD_LOG_PANEL (self));
+  g_assert (allocation != NULL);
+  g_assert (IDE_IS_TERMINAL (terminal));
+
+  pty = vte_terminal_get_pty (VTE_TERMINAL (self->terminal));
+
+  if (self->pipeline != NULL && pty != NULL)
+    {
+      if (vte_pty_get_size (pty, &rows, &columns, NULL))
+        _ide_build_pipeline_set_pty_size (self->pipeline, rows, columns);
+    }
+}
+
 static void
 ide_build_log_panel_init (IdeBuildLogPanel *self)
 {
@@ -289,6 +331,12 @@ ide_build_log_panel_init (IdeBuildLogPanel *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
+  g_signal_connect_object (self->terminal,
+                           "size-allocate",
+                           G_CALLBACK (terminal_size_allocate),
+                           self,
+                           G_CONNECT_SWAPPED | G_CONNECT_AFTER);
+
   g_signal_connect_object (self->terminal,
                            "window-title-changed",
                            G_CALLBACK (ide_build_log_panel_window_title_changed),
