@@ -24,6 +24,7 @@
 #include "ide-debug.h"
 #include "ide-enums.h"
 
+#include "application/ide-application.h"
 #include "config/ide-configuration.h"
 #include "config/ide-configuration-manager.h"
 #include "buildsystem/ide-environment.h"
@@ -44,6 +45,8 @@ typedef struct
   gchar          *runtime_id;
   gchar          *append_path;
 
+  GFile          *build_commands_dir;
+
   IdeEnvironment *environment;
 
   GHashTable     *internal;
@@ -53,6 +56,7 @@ typedef struct
 
   guint           dirty : 1;
   guint           debug : 1;
+  guint           has_attached : 1;
 
   /*
    * This is used to determine if we can make progress building
@@ -71,6 +75,7 @@ enum {
   PROP_APPEND_PATH,
   PROP_APP_ID,
   PROP_BUILD_COMMANDS,
+  PROP_BUILD_COMMANDS_DIR,
   PROP_CONFIG_OPTS,
   PROP_DEBUG,
   PROP_DIRTY,
@@ -138,10 +143,7 @@ ide_configuration_real_get_runtime (IdeConfiguration *self)
     {
       IdeContext *context = ide_object_get_context (IDE_OBJECT (self));
       IdeRuntimeManager *runtime_manager = ide_context_get_runtime_manager (context);
-      IdeRuntime *runtime = ide_runtime_manager_get_runtime (runtime_manager, priv->runtime_id);
-
-      if (runtime != NULL)
-        return g_object_ref (runtime);
+      return ide_runtime_manager_get_runtime (runtime_manager, priv->runtime_id);;
     }
 
   return NULL;
@@ -228,39 +230,13 @@ ide_configuration_real_set_runtime (IdeConfiguration *self,
   ide_configuration_set_runtime_id (self, runtime_id);
 }
 
-static void
-ide_configuration_constructed (GObject *object)
-{
-  IdeConfiguration *self = (IdeConfiguration *)object;
-  IdeContext *context;
-  IdeRuntimeManager *runtime_manager;
-
-  G_OBJECT_CLASS (ide_configuration_parent_class)->constructed (object);
-
-  if (ide_object_is_unloading (IDE_OBJECT (self)))
-    return;
-
-  /* Allow ourselves to be run from unit tests without a valid context */
-  if (NULL != (context = ide_object_get_context (IDE_OBJECT (self))))
-    {
-      runtime_manager = ide_context_get_runtime_manager (context);
-
-      g_signal_connect_object (runtime_manager,
-                               "items-changed",
-                               G_CALLBACK (ide_configuration_runtime_manager_items_changed),
-                               self,
-                               G_CONNECT_SWAPPED);
-
-      ide_configuration_runtime_manager_items_changed (self, 0, 0, 0, runtime_manager);
-    }
-}
-
 static void
 ide_configuration_finalize (GObject *object)
 {
   IdeConfiguration *self = (IdeConfiguration *)object;
   IdeConfigurationPrivate *priv = ide_configuration_get_instance_private (self);
 
+  g_clear_object (&priv->build_commands_dir);
   g_clear_object (&priv->environment);
 
   g_clear_pointer (&priv->build_commands, g_strfreev);
@@ -294,6 +270,10 @@ ide_configuration_get_property (GObject    *object,
       g_value_set_boxed (value, ide_configuration_get_build_commands (self));
       break;
 
+    case PROP_BUILD_COMMANDS_DIR:
+      g_value_set_object (value, ide_configuration_get_build_commands_dir (self));
+      break;
+
     case PROP_DEBUG:
       g_value_set_boolean (value, ide_configuration_get_debug (self));
       break;
@@ -377,6 +357,10 @@ ide_configuration_set_property (GObject      *object,
       ide_configuration_set_build_commands (self, g_value_get_boxed (value));
       break;
 
+    case PROP_BUILD_COMMANDS_DIR:
+      ide_configuration_set_build_commands_dir (self, g_value_get_object (value));
+      break;
+
     case PROP_DEBUG:
       ide_configuration_set_debug (self, g_value_get_boolean (value));
       break;
@@ -439,7 +423,6 @@ ide_configuration_class_init (IdeConfigurationClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  object_class->constructed = ide_configuration_constructed;
   object_class->finalize = ide_configuration_finalize;
   object_class->get_property = ide_configuration_get_property;
   object_class->set_property = ide_configuration_set_property;
@@ -461,6 +444,13 @@ ide_configuration_class_init (IdeConfigurationClass *klass)
                         G_TYPE_STRV,
                         (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
 
+  properties [PROP_BUILD_COMMANDS_DIR] =
+    g_param_spec_object ("build-commands-dir",
+                        "Build commands Dir",
+                        "Directory to run build commands from",
+                        G_TYPE_FILE,
+                        (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
+
   properties [PROP_CONFIG_OPTS] =
     g_param_spec_string ("config-opts",
                          "Config Options",
@@ -582,20 +572,15 @@ static void
 ide_configuration_init (IdeConfiguration *self)
 {
   IdeConfigurationPrivate *priv = ide_configuration_get_instance_private (self);
+  g_autoptr(IdeEnvironment) env = ide_environment_new ();
 
   priv->runtime_id = g_strdup ("host");
   priv->debug = TRUE;
-  priv->environment = ide_environment_new ();
   priv->parallelism = -1;
   priv->locality = IDE_BUILD_LOCALITY_DEFAULT;
-
   priv->internal = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, _value_free);
 
-  g_signal_connect_object (priv->environment,
-                           "changed",
-                           G_CALLBACK (ide_configuration_environment_changed),
-                           self,
-                           G_CONNECT_SWAPPED);
+  ide_configuration_set_environment (self, env);
 }
 
 /**
@@ -655,26 +640,28 @@ ide_configuration_set_runtime_id (IdeConfiguration *self,
 
   if (g_strcmp0 (runtime_id, priv->runtime_id) != 0)
     {
-      IdeRuntimeManager *runtime_manager;
-      IdeContext *context;
-      IdeRuntime *runtime;
-
+      priv->runtime_ready = FALSE;
       g_free (priv->runtime_id);
       priv->runtime_id = g_strdup (runtime_id);
 
+      ide_configuration_set_dirty (self, TRUE);
+
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_RUNTIME_ID]);
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_RUNTIME]);
 
-      context = ide_object_get_context (IDE_OBJECT (self));
-      runtime_manager = ide_context_get_runtime_manager (context);
-      ide_configuration_runtime_manager_items_changed (self, 0, 0, 0, runtime_manager);
+      if (priv->has_attached)
+        {
+          IdeRuntimeManager *runtime_manager;
+          IdeContext *context;
 
-      runtime = ide_configuration_get_runtime (self);
-      if (runtime != NULL)
-        ide_runtime_prepare_configuration (runtime, self);
+          g_assert (IDE_IS_MAIN_THREAD ());
 
-      ide_configuration_set_dirty (self, TRUE);
-      ide_configuration_emit_changed (self);
+          context = ide_object_get_context (IDE_OBJECT (self));
+          runtime_manager = ide_context_get_runtime_manager (context);
+          ide_configuration_runtime_manager_items_changed (self, 0, 0, 0, runtime_manager);
+
+          ide_configuration_emit_changed (self);
+        }
     }
 }
 
@@ -938,13 +925,28 @@ ide_configuration_set_environment (IdeConfiguration *self,
 
   g_return_if_fail (IDE_IS_CONFIGURATION (self));
 
-  g_clear_object (&priv->environment);
-  priv->environment = g_object_ref (environment);
-  g_signal_connect_object (priv->environment,
-                           "changed",
-                           G_CALLBACK (ide_configuration_environment_changed),
-                           self,
-                           G_CONNECT_SWAPPED);
+  if (priv->environment != environment)
+    {
+      if (priv->environment != NULL)
+        {
+          g_signal_handlers_disconnect_by_func (priv->environment,
+                                                G_CALLBACK (ide_configuration_environment_changed),
+                                                self);
+          g_clear_object (&priv->environment);
+        }
+
+      if (environment != NULL)
+        {
+          priv->environment = g_object_ref (environment);
+          g_signal_connect_object (priv->environment,
+                                   "changed",
+                                   G_CALLBACK (ide_configuration_environment_changed),
+                                   self,
+                                   G_CONNECT_SWAPPED);
+        }
+
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ENVIRON]);
+    }
 }
 
 const gchar *
@@ -1442,3 +1444,68 @@ ide_configuration_set_locality (IdeConfiguration *self,
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_LOCALITY]);
     }
 }
+
+/**
+ * ide_configuration_get_build_commands_dir:
+ * @self: a #IdeConfiguration
+ *
+ * Returns: (transfer none) (nullable): a #GFile or %NULL
+ */
+GFile *
+ide_configuration_get_build_commands_dir (IdeConfiguration *self)
+{
+  IdeConfigurationPrivate *priv = ide_configuration_get_instance_private (self);
+
+  g_return_val_if_fail (IDE_IS_CONFIGURATION (self), NULL);
+
+  return priv->build_commands_dir;
+}
+
+void
+ide_configuration_set_build_commands_dir (IdeConfiguration *self,
+                                          GFile            *build_commands_dir)
+{
+  IdeConfigurationPrivate *priv = ide_configuration_get_instance_private (self);
+
+  g_return_if_fail (IDE_IS_CONFIGURATION (self));
+  g_return_if_fail (!build_commands_dir || G_IS_FILE (build_commands_dir));
+
+  if (g_set_object (&priv->build_commands_dir, build_commands_dir))
+    g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_BUILD_COMMANDS_DIR]);
+}
+
+void
+_ide_configuration_attach (IdeConfiguration *self)
+{
+  IdeConfigurationPrivate *priv = ide_configuration_get_instance_private (self);
+  IdeRuntimeManager *runtime_manager;
+  IdeContext *context;
+
+  g_return_if_fail (IDE_IS_MAIN_THREAD ());
+  g_return_if_fail (IDE_IS_CONFIGURATION (self));
+  g_return_if_fail (priv->has_attached == FALSE);
+
+  priv->has_attached = TRUE;
+
+  /*
+   * We don't start monitoring changed events until we've gotten back
+   * to the main loop (in case of threaded loaders) which happens from
+   * the point where the configuration is added ot the config manager.
+   */
+
+  if (!(context = ide_object_get_context (IDE_OBJECT (self))))
+    {
+      g_critical ("Attempt to register configuration without a context");
+      return;
+    }
+
+  runtime_manager = ide_context_get_runtime_manager (context);
+
+  g_signal_connect_object (runtime_manager,
+                           "items-changed",
+                           G_CALLBACK (ide_configuration_runtime_manager_items_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  ide_configuration_runtime_manager_items_changed (self, 0, 0, 0, runtime_manager);
+}
