@@ -468,6 +468,7 @@ ide_debug_manager_load_file_cb (GObject      *object,
   if (buffer == NULL)
     {
       g_warning ("%s", error->message);
+      g_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
@@ -479,6 +480,8 @@ ide_debug_manager_load_file_cb (GObject      *object,
 
   ide_debug_manager_mark_stopped (self, buffer, breakpoint);
 
+  g_task_return_boolean (task, TRUE);
+
   IDE_EXIT;
 }
 
@@ -797,11 +800,10 @@ static void
 ide_debug_manager_reset_breakpoints_cb (gpointer item,
                                         gpointer user_data)
 {
-  IdeDebugManager *self = user_data;
   IdeDebuggerBreakpoint *breakpoint = item;
 
   g_assert (IDE_IS_DEBUGGER_BREAKPOINT (breakpoint));
-  g_assert (IDE_IS_DEBUG_MANAGER (self));
+  g_assert (IDE_IS_DEBUG_MANAGER (user_data));
 
   _ide_debugger_breakpoint_reset (breakpoint);
 }
