@@ -20,12 +20,15 @@
 
 #include <glib/gi18n.h>
 
+#include "ide-debug.h"
+
 #include "config/ide-configuration.h"
 #include "devices/ide-device.h"
 
 typedef struct
 {
   gchar *display_name;
+  gchar *icon_name;
   gchar *id;
 } IdeDevicePrivate;
 
@@ -34,12 +37,12 @@ G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (IdeDevice, ide_device, IDE_TYPE_OBJECT)
 enum {
   PROP_0,
   PROP_DISPLAY_NAME,
+  PROP_ICON_NAME,
   PROP_ID,
-  PROP_SYSTEM_TYPE,
-  LAST_PROP
+  N_PROPS
 };
 
-static GParamSpec *properties [LAST_PROP];
+static GParamSpec *properties [N_PROPS];
 
 /**
  * ide_device_get_display_name:
@@ -79,6 +82,52 @@ ide_device_set_display_name (IdeDevice   *device,
     }
 }
 
+/**
+ * ide_device_get_icon_name:
+ * @self: a #IdeDevice
+ *
+ * Gets the icon to use when displaying the device in UI elements.
+ *
+ * Returns: (nullable): an icon-name or %NULL
+ *
+ * Since: 3.28
+ */
+const gchar *
+ide_device_get_icon_name (IdeDevice *self)
+{
+  IdeDevicePrivate *priv = ide_device_get_instance_private (self);
+
+  g_return_val_if_fail (IDE_IS_DEVICE (self), NULL);
+
+  return priv->icon_name;
+}
+
+/**
+ * ide_device_set_icon_name:
+ * @self: a #IdeDevice
+ *
+ * Sets the icon-name property.
+ *
+ * This is the icon that is displayed with the device name in UI elements.
+ *
+ * Since: 3.28
+ */
+void
+ide_device_set_icon_name (IdeDevice   *self,
+                          const gchar *icon_name)
+{
+  IdeDevicePrivate *priv = ide_device_get_instance_private (self);
+
+  g_return_if_fail (IDE_IS_DEVICE (self));
+
+  if (g_strcmp0 (icon_name, priv->icon_name) != 0)
+    {
+      g_free (priv->icon_name);
+      priv->icon_name = g_strdup (icon_name);
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ICON_NAME]);
+    }
+}
+
 /**
  * ide_device_get_id:
  *
@@ -113,31 +162,26 @@ ide_device_set_id (IdeDevice   *device,
     }
 }
 
-/**
- * ide_device_get_system_type:
- *
- * This is the description of the system we are building for. Commonly, this
- * is referred to as a "system_type". A combination of the machine architecture
- * such as x86_64, the operating system, and the libc.
- *
- * "x86_64-linux-gnu" might be one such system.
- *
- * Returns: A string containing the system type.
- */
-const gchar *
-ide_device_get_system_type (IdeDevice *device)
+static void
+ide_device_real_get_info_async (IdeDevice           *self,
+                                GCancellable        *cancellable,
+                                GAsyncReadyCallback  callback,
+                                gpointer             user_data)
 {
-  IdeDeviceClass *klass;
-  const gchar *ret = NULL;
+  g_task_report_new_error (self, callback, user_data,
+                           ide_device_real_get_info_async,
+                           G_IO_ERROR,
+                           G_IO_ERROR_NOT_SUPPORTED,
+                           "%s has not implemented get_info_async()",
+                           G_OBJECT_TYPE_NAME (self));
+}
 
-  g_return_val_if_fail (IDE_IS_DEVICE (device), NULL);
-
-  klass = IDE_DEVICE_GET_CLASS (device);
-
-  if (klass->get_system_type)
-    ret = klass->get_system_type (device);
-
-  return ret;
+static IdeDeviceInfo *
+ide_device_real_get_info_finish (IdeDevice     *self,
+                                 GAsyncResult  *result,
+                                 GError       **error)
+{
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 static void
@@ -166,12 +210,12 @@ ide_device_get_property (GObject    *object,
       g_value_set_string (value, ide_device_get_display_name (self));
       break;
 
-    case PROP_ID:
-      g_value_set_string (value, ide_device_get_id (self));
+    case PROP_ICON_NAME:
+      g_value_set_string (value, ide_device_get_icon_name (self));
       break;
 
-    case PROP_SYSTEM_TYPE:
-      g_value_set_string (value, ide_device_get_system_type (self));
+    case PROP_ID:
+      g_value_set_string (value, ide_device_get_id (self));
       break;
 
     default:
@@ -193,6 +237,10 @@ ide_device_set_property (GObject      *object,
       ide_device_set_display_name (self, g_value_get_string (value));
       break;
 
+    case PROP_ICON_NAME:
+      ide_device_set_icon_name (self, g_value_get_string (value));
+      break;
+
     case PROP_ID:
       ide_device_set_id (self, g_value_get_string (value));
       break;
@@ -211,6 +259,9 @@ ide_device_class_init (IdeDeviceClass *klass)
   object_class->get_property = ide_device_get_property;
   object_class->set_property = ide_device_set_property;
 
+  klass->get_info_async = ide_device_real_get_info_async;
+  klass->get_info_finish = ide_device_real_get_info_finish;
+
   properties [PROP_DISPLAY_NAME] =
     g_param_spec_string ("display-name",
                          "Display Name",
@@ -218,6 +269,21 @@ ide_device_class_init (IdeDeviceClass *klass)
                          NULL,
                          (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+  /**
+   * IdeDevice:icon-name:
+   *
+   * The "icon-name" property is the icon to display with the device in
+   * various UI elements of Builder.
+   *
+   * Since: 3.28
+   */
+  properties [PROP_ICON_NAME] =
+    g_param_spec_string ("icon-name",
+                         "Icon Name",
+                         "Icon Name",
+                         NULL,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
   properties [PROP_ID] =
     g_param_spec_string ("id",
                          "ID",
@@ -225,14 +291,7 @@ ide_device_class_init (IdeDeviceClass *klass)
                          NULL,
                          (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
-  properties [PROP_SYSTEM_TYPE] =
-    g_param_spec_string ("system-type",
-                         "System Type",
-                         "The system type for which to compile.",
-                         NULL,
-                         (G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-
-  g_object_class_install_properties (object_class, LAST_PROP, properties);
+  g_object_class_install_properties (object_class, N_PROPS, properties);
 }
 
 static void
@@ -261,3 +320,65 @@ ide_device_error_quark (void)
 
   return quark;
 }
+
+/**
+ * ide_device_get_info_async:
+ * @self: an #IdeDevice
+ * @cancellable: (nullable): a #GCancellable or %NULL
+ * @callback: a callback to execute upon completion
+ * @user_data: closure data for @callback
+ *
+ * Asynchronously requests information about the device.
+ *
+ * Some information may not be available until after a connection
+ * has been established. This allows the device to connect before
+ * fetching that information.
+ *
+ * Since: 3.28
+ */
+void
+ide_device_get_info_async (IdeDevice           *self,
+                           GCancellable        *cancellable,
+                           GAsyncReadyCallback  callback,
+                           gpointer             user_data)
+{
+  IDE_ENTRY;
+
+  g_return_if_fail (IDE_IS_DEVICE (self));
+  g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
+
+  IDE_DEVICE_GET_CLASS (self)->get_info_async (self, cancellable, callback, user_data);
+
+  IDE_EXIT;
+}
+
+/**
+ * ide_device_get_info_finish:
+ * @self: an #IdeDevice
+ * @result: a #GAsyncResult provided to callback
+ * @error: a location for a #GError, or %NULL
+ *
+ * Completes an asynchronous request to load the information about a device.
+ *
+ * Returns: (transfer full): an #IdeDeviceInfo or %NULL and @error is set
+ *
+ * Since: 3.28
+ */
+IdeDeviceInfo *
+ide_device_get_info_finish (IdeDevice     *self,
+                            GAsyncResult  *result,
+                            GError       **error)
+{
+  IdeDeviceInfo *ret;
+
+  IDE_ENTRY;
+
+  g_return_val_if_fail (IDE_IS_DEVICE (self), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
+
+  ret = IDE_DEVICE_GET_CLASS (self)->get_info_finish (self, result, error);
+
+  g_return_val_if_fail (!ret || IDE_IS_DEVICE_INFO (ret), NULL);
+
+  IDE_RETURN (ret);
+}
