@@ -317,8 +317,10 @@ ide_diagnostics_group_diagnose_cb (GObject      *object,
 
   diagnostics = ide_diagnostic_provider_diagnose_finish (provider, result, &error);
 
-  if (error != NULL)
-    g_warning ("%s", error->message);
+  if (error != NULL &&
+      !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) &&
+      !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED))
+    g_debug ("%s", error->message);
 
   /*
    * This fetches the group our provider belongs to. Since the group is
@@ -435,10 +437,7 @@ ide_diagnostics_group_diagnose_foreach (IdeExtensionSetAdapter *adapter,
 
   context = ide_object_get_context (IDE_OBJECT (self));
 
-  file = g_object_new (IDE_TYPE_FILE,
-                       "context", context,
-                       "file", group->file,
-                       NULL);
+  file = ide_file_new (context, group->file);
 
 #ifdef IDE_ENABLE_TRACE
   {
@@ -1278,3 +1277,30 @@ ide_diagnostics_manager_get_sequence_for_file (IdeDiagnosticsManager *self,
 
   return 0;
 }
+
+/**
+ * ide_diagnostics_manager_rediagnose:
+ * @self: an #IdeDiagnosticsManager
+ * @buffer: an #IdeBuffer
+ *
+ * Requests that the diagnostics be reloaded for @buffer.
+ *
+ * You may want to call this if you changed something that a buffer depends on,
+ * and want to seamlessly update its diagnostics with that updated information.
+ *
+ * Internally, this is the same as @buffer emitting the #IdeBuffer::changed
+ * signal.
+ *
+ * Since: 3.28
+ */
+void
+ide_diagnostics_manager_rediagnose (IdeDiagnosticsManager *self,
+                                    IdeBuffer             *buffer)
+{
+  g_return_if_fail (IDE_IS_DIAGNOSTICS_MANAGER (self));
+  g_return_if_fail (IDE_IS_BUFFER (buffer));
+  g_return_if_fail (ide_buffer_get_context (buffer) ==
+                    ide_object_get_context (IDE_OBJECT (self)));
+
+  ide_diagnostics_manager_buffer_changed (self, buffer);
+}
