@@ -41,13 +41,16 @@ struct _IdeEditorSidebar
 {
   IdeLayoutPane      parent_instance;
 
+  GSettings         *settings;
+  GListModel        *open_pages;
+
   /* Template widgets */
   GtkBox            *box;
   GtkStackSwitcher  *stack_switcher;
   GtkListBox        *open_pages_list_box;
   GtkBox            *open_pages_section;
   GtkLabel          *section_title;
-  GtkImage          *section_menu_button;
+  DzlMenuButton     *section_menu_button;
   GtkStack          *stack;
 };
 
@@ -57,16 +60,29 @@ static void
 ide_editor_sidebar_update_title (IdeEditorSidebar *self)
 {
   g_autofree gchar *title = NULL;
+  const gchar *icon_name = NULL;
+  const gchar *menu_id = NULL;
   GtkWidget *visible_child;
 
   g_assert (IDE_IS_EDITOR_SIDEBAR (self));
 
   if (NULL != (visible_child = gtk_stack_get_visible_child (self->stack)))
-    gtk_container_child_get (GTK_CONTAINER (self->stack), visible_child,
-                             "title", &title,
-                             NULL);
+    {
+      menu_id = g_object_get_data (G_OBJECT (visible_child),
+                                   "IDE_EDITOR_SIDEBAR_MENU_ID");
+      icon_name = g_object_get_data (G_OBJECT (visible_child),
+                                     "IDE_EDITOR_SIDEBAR_MENU_ICON_NAME");
+      gtk_container_child_get (GTK_CONTAINER (self->stack), visible_child,
+                               "title", &title,
+                               NULL);
+    }
 
   gtk_label_set_label (self->section_title, title);
+  g_object_set (self->section_menu_button,
+                "icon-name", icon_name,
+                "menu-id", menu_id,
+                "visible", menu_id != NULL,
+                NULL);
 }
 
 static void
@@ -104,6 +120,43 @@ ide_editor_sidebar_open_pages_row_activated (IdeEditorSidebar *self,
   gtk_widget_grab_focus (GTK_WIDGET (view));
 }
 
+static void
+ide_editor_sidebar_open_pages_items_changed (IdeEditorSidebar *self,
+                                             guint             position,
+                                             guint             added,
+                                             guint             removed,
+                                             GListModel       *model)
+{
+  g_assert (IDE_IS_EDITOR_SIDEBAR (self));
+  g_assert (G_IS_LIST_MODEL (model));
+
+  /*
+   * Sets the visibility of our page list widgets only when the listmodel has
+   * views within it. We try to be careful about being safe when the widget is
+   * in destruction and an items-changed signal arrives.
+   */
+
+  if (self->open_pages_section != NULL)
+    {
+      gboolean has_items = g_list_model_get_n_items (model) > 0;
+      gboolean show = g_settings_get_boolean (self->settings, "show-open-files");
+
+      gtk_widget_set_visible (GTK_WIDGET (self->open_pages_section), show && has_items);
+    }
+}
+
+static void
+ide_editor_sidebar_changed_show_open_files (IdeEditorSidebar *self,
+                                            const gchar      *key,
+                                            GSettings        *settings)
+{
+  g_assert (IDE_IS_EDITOR_SIDEBAR (self));
+  g_assert (G_IS_SETTINGS (settings));
+
+  if (self->open_pages != NULL)
+    ide_editor_sidebar_open_pages_items_changed (self, 0, 0, 0, self->open_pages);
+}
+
 static void
 ide_editor_sidebar_destroy (GtkWidget *widget)
 {
@@ -112,6 +165,9 @@ ide_editor_sidebar_destroy (GtkWidget *widget)
   if (self->open_pages_list_box != NULL)
     gtk_list_box_bind_model (self->open_pages_list_box, NULL, NULL, NULL, NULL);
 
+  g_clear_object (&self->open_pages);
+  g_clear_object (&self->settings);
+
   GTK_WIDGET_CLASS (ide_editor_sidebar_parent_class)->destroy (widget);
 }
 
@@ -147,6 +203,16 @@ ide_editor_sidebar_init (IdeEditorSidebar *self)
                             "notify::visible-child",
                             G_CALLBACK (ide_editor_sidebar_stack_notify_visible_child),
                             self);
+
+  self->settings = g_settings_new ("org.gnome.builder");
+
+  g_signal_connect_object (self->settings,
+                           "changed::show-open-files",
+                           G_CALLBACK (ide_editor_sidebar_changed_show_open_files),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  ide_editor_sidebar_changed_show_open_files (self, NULL, self->settings);
 }
 
 /**
@@ -393,33 +459,10 @@ create_open_page_row (gpointer item,
   return GTK_WIDGET (row);
 }
 
-static void
-ide_editor_sidebar_open_pages_items_changed (IdeEditorSidebar *self,
-                                             guint             position,
-                                             guint             added,
-                                             guint             removed,
-                                             GListModel       *model)
-{
-  g_assert (IDE_IS_EDITOR_SIDEBAR (self));
-  g_assert (G_IS_LIST_MODEL (model));
-
-  /*
-   * Sets the visibility of our page list widgets only when the listmodel has
-   * views within it. We try to be careful about being safe when the widget is
-   * in destruction and an items-changed signal arrives.
-   */
-
-  if (self->open_pages_section != NULL)
-    {
-      gboolean has_items = g_list_model_get_n_items (model) > 0;
-      gtk_widget_set_visible (GTK_WIDGET (self->open_pages_section), has_items);
-    }
-}
-
 /**
  * _ide_editor_sidebar_set_open_pages:
  * @self: a #IdeEditorSidebar
- * @open_pages: A #GListModel describing the open pages
+ * @open_pages: a #GListModel describing the open pages
  *
  * This private function is used to set the GListModel to use for the list
  * of open pages in the sidebar. It should contain a list of IdeLayoutView
@@ -434,6 +477,8 @@ _ide_editor_sidebar_set_open_pages (IdeEditorSidebar *self,
   g_return_if_fail (!open_pages ||
                     g_list_model_get_item_type (open_pages) == IDE_TYPE_LAYOUT_VIEW);
 
+  g_set_object (&self->open_pages, open_pages);
+
   if (open_pages != NULL)
     g_signal_connect_object (open_pages,
                              "items-changed",
