@@ -58,6 +58,9 @@ G_DEFINE_TYPE (IdeFile, ide_file, IDE_TYPE_OBJECT)
 
 static GParamSpec *properties [LAST_PROP];
 
+G_LOCK_DEFINE (files_cache);
+static GHashTable *files_cache;
+
 const gchar *
 _ide_file_get_content_type (IdeFile *self)
 {
@@ -217,9 +220,23 @@ ide_file_get_path (IdeFile *self)
 
   if (g_once_init_enter (&self->path))
     {
-      gchar *path;
+      IdeContext *context;
+      gchar *path = NULL;
+
+      context = ide_object_get_context (IDE_OBJECT (self));
+
+      if (context != NULL)
+        {
+          IdeVcs *vcs = ide_context_get_vcs (context);
+          GFile *workdir = ide_vcs_get_working_directory (vcs);
+
+          if (g_file_has_prefix (self->file, workdir))
+            path = g_file_get_relative_path (workdir, self->file);
+        }
+
+      if (path == NULL)
+        path = g_file_get_path (self->file);
 
-      path = g_file_get_path (self->file);
       g_once_init_leave (&self->path, path);
     }
 
@@ -335,6 +352,24 @@ ide_file_load_settings_finish (IdeFile              *self,
   IDE_RETURN (ret);
 }
 
+/**
+ * ide_file_peek_settings:
+ * @self: a #IdeFile
+ *
+ * Returns the #IdeFileSettings if they've been loaded.
+ *
+ * Returns: (nullable) (transfer none): an #IdeFileSettings or %NULL
+ *
+ * Since: 3.28
+ */
+IdeFileSettings *
+ide_file_peek_settings (IdeFile *self)
+{
+  g_return_val_if_fail (IDE_IS_FILE (self), NULL);
+
+  return self->file_settings;
+}
+
 /**
  * ide_file_get_temporary_id:
  * @self: (in): an #IdeFile.
@@ -374,6 +409,22 @@ ide_file_get_is_temporary (IdeFile *self)
   return (self->temporary_id != 0);
 }
 
+static void
+ide_file_dispose (GObject *object)
+{
+  IdeFile *self = (IdeFile *)object;
+
+  if (self->file != NULL)
+    {
+      G_LOCK (files_cache);
+      if (files_cache != NULL)
+        g_hash_table_remove (files_cache, self->file);
+      G_UNLOCK (files_cache);
+    }
+
+  G_OBJECT_CLASS (ide_file_parent_class)->dispose (object);
+}
+
 static void
 ide_file_finalize (GObject *object)
 {
@@ -462,6 +513,7 @@ ide_file_class_init (IdeFileClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+  object_class->dispose = ide_file_dispose;
   object_class->finalize = ide_file_finalize;
   object_class->get_property = ide_file_get_property;
   object_class->set_property = ide_file_set_property;
@@ -519,7 +571,6 @@ has_suffix (const gchar          *path,
             const gchar * const *allowed_suffixes)
 {
   const gchar *dot;
-  gsize i;
 
   dot = strrchr (path, '.');
   if (!dot)
@@ -527,7 +578,7 @@ has_suffix (const gchar          *path,
 
   dot++;
 
-  for (i = 0; allowed_suffixes [i]; i++)
+  for (guint i = 0; allowed_suffixes [i]; i++)
     {
       if (g_str_equal (dot, allowed_suffixes [i]))
         return TRUE;
@@ -548,8 +599,8 @@ ide_file_find_other_worker (GTask        *task,
   const gchar **target = NULL;
   g_autofree gchar *prefix = NULL;
   g_autofree gchar *uri = NULL;
-  gsize i;
 
+  g_assert (G_IS_TASK (task));
   g_assert (IDE_IS_FILE (self));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
@@ -574,7 +625,7 @@ ide_file_find_other_worker (GTask        *task,
 
   prefix = g_strndup (uri, strrchr (uri, '.') - uri);
 
-  for (i = 0; target [i]; i++)
+  for (guint i = 0; target [i]; i++)
     {
       g_autofree gchar *new_uri = NULL;
       g_autoptr(GFile) gfile = NULL;
@@ -584,23 +635,12 @@ ide_file_find_other_worker (GTask        *task,
 
       if (g_file_query_exists (gfile, cancellable))
         {
-          g_autofree gchar *path = NULL;
-          IdeContext *context;
-          IdeVcs *vcs;
-          IdeFile *ret;
-          GFile *workdir;
+          IdeContext *context = ide_object_get_context (IDE_OBJECT (self));
 
-          context = ide_object_get_context (IDE_OBJECT (self));
-          vcs = ide_context_get_vcs (context);
-          workdir = ide_vcs_get_working_directory (vcs);
-          path = g_file_get_relative_path (workdir, gfile);
+          g_task_return_pointer (task,
+                                 ide_file_new (context, gfile),
+                                 g_object_unref);
 
-          ret = g_object_new (IDE_TYPE_FILE,
-                              "context", context,
-                              "path", path,
-                              "file", gfile,
-                              NULL);
-          g_task_return_pointer (task, ret, g_object_unref);
           return;
         }
     }
@@ -649,6 +689,23 @@ ide_file_find_other_finish (IdeFile       *self,
   return g_task_propagate_pointer (G_TASK (result), error);
 }
 
+static IdeFile *
+lookup_by_gfile_locked (GFile *file)
+{
+  IdeFile *ret;
+
+  g_assert (G_IS_FILE (file));
+
+  if (files_cache == NULL)
+    files_cache = g_hash_table_new_full (g_file_hash, (GEqualFunc)g_file_equal, NULL, NULL);
+
+  ret = g_hash_table_lookup (files_cache, file);
+  if (ret != NULL)
+    g_object_ref (ret);
+
+  return ret;
+}
+
 /**
  * ide_file_new:
  * @context: (allow-none): An #IdeContext or %NULL.
@@ -662,13 +719,33 @@ IdeFile *
 ide_file_new (IdeContext *context,
               GFile      *file)
 {
+  g_autoptr(IdeFile) ret = NULL;
+
   g_return_val_if_fail (!context || IDE_IS_CONTEXT (context), NULL);
   g_return_val_if_fail (G_IS_FILE (file), NULL);
 
-  return g_object_new (IDE_TYPE_FILE,
-                       "context", context,
-                       "file", file,
-                       NULL);
+  G_LOCK (files_cache);
+
+  ret = lookup_by_gfile_locked (file);
+
+  if (ret == NULL)
+    {
+      ret = g_object_new (IDE_TYPE_FILE,
+                          "context", context,
+                          "file", file,
+                          NULL);
+
+      /* Only cache this item if has an IdeContext. We might want
+       * to make a file cache per-context, but we can hold off on
+       * that until we know we need it.
+       */
+      if (context != NULL)
+        g_hash_table_insert (files_cache, file, ret);
+    }
+
+  G_UNLOCK (files_cache);
+
+  return g_steal_pointer (&ret);
 }
 
 IdeFile *
@@ -676,18 +753,21 @@ ide_file_new_for_path (IdeContext  *context,
                        const gchar *path)
 {
   g_autoptr(GFile) file = NULL;
-  IdeFile *ret;
 
   g_return_val_if_fail (!context || IDE_IS_CONTEXT (context), NULL);
   g_return_val_if_fail (path != NULL, NULL);
 
-  file = g_file_new_for_path (path);
-  ret = g_object_new (IDE_TYPE_FILE,
-                      "context", context,
-                      "file", file,
-                      NULL);
+  if (context != NULL && !g_path_is_absolute (path))
+    {
+      IdeVcs *vcs = ide_context_get_vcs (context);
+      GFile *workdir = ide_vcs_get_working_directory (vcs);
 
-  return ret;
+      file = g_file_get_child (workdir, path);
+    }
+  else
+    file = g_file_new_for_path (path);
+
+  return ide_file_new (context, file);
 }
 
 gint
