@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include <glib-object.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
