@@ -66,8 +66,6 @@ struct _IdeGreeterPerspective
   GtkScrolledWindow    *scrolled_window;
   DzlPriorityBox       *genesis_buttons;
   DzlPriorityBox       *sections_container;
-
-  gint                  selected_count;
 };
 
 typedef struct
@@ -290,8 +288,7 @@ static void
 ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
                                       GtkButton             *open_button)
 {
-  g_autoptr(GSettings) settings = NULL;
-  g_autofree gchar *projects_dir = NULL;
+  g_autoptr(GFile) projects_dir = NULL;
   GtkFileChooserDialog *dialog;
   GtkWidget *toplevel;
   PeasEngine *engine;
@@ -418,9 +415,8 @@ ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
   if (last_priority == G_MAXINT64)
     gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), all_filter);
 
-  settings = g_settings_new ("org.gnome.builder");
-  projects_dir = g_settings_get_string (settings, "projects-directory");
-  gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), projects_dir);
+  projects_dir = ide_application_get_projects_directory (IDE_APPLICATION_DEFAULT);
+  gtk_file_chooser_set_current_folder_file (GTK_FILE_CHOOSER (dialog), projects_dir, NULL);
 
   gtk_window_present (GTK_WINDOW (dialog));
 }
@@ -630,6 +626,7 @@ run_genesis_addin (PeasExtensionSet *set,
   g_assert (IDE_IS_GREETER_PERSPECTIVE (state->self));
   g_assert (state->name != NULL);
   g_assert (IDE_IS_GENESIS_ADDIN (addin));
+  g_assert (G_IS_CANCELLABLE (state->self->cancellable));
 
   if (g_strcmp0 (state->name, G_OBJECT_TYPE_NAME (addin)) == 0)
     {
@@ -664,7 +661,9 @@ static void
 ide_greeter_perspective_genesis_continue_clicked (IdeGreeterPerspective *self,
                                                   GtkButton             *button)
 {
+  g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
   g_assert (GTK_IS_BUTTON (button));
+
   ide_greeter_perspective_genesis_continue (self);
 }
 
@@ -746,16 +745,15 @@ ide_greeter_perspective_info_bar_response (IdeGreeterPerspective *self,
 static gchar *
 get_project_directory (const gchar *name)
 {
-  g_autoptr(GSettings) settings = NULL;
-  g_autofree gchar *projects = NULL;
+  g_autoptr(GFile) projects = NULL;
+  g_autoptr(GFile) child = NULL;
 
-  settings = g_settings_new ("org.gnome.builder");
-  projects = g_settings_get_string (settings, "projects-directory");
+  g_assert (IDE_IS_MAIN_THREAD ());
 
-  if (!g_path_is_absolute (projects))
-    return g_build_filename (g_get_home_dir (), projects, name, NULL);
-  else
-    return g_build_filename (projects, name, NULL);
+  projects = ide_application_get_projects_directory (IDE_APPLICATION_DEFAULT);
+  child = g_file_get_child (projects, name);
+
+  return g_file_get_path (child);
 }
 
 static void
@@ -904,12 +902,49 @@ ide_greeter_perspective_project_activated (IdeGreeterPerspective *self,
                                            IdeProjectInfo        *project_info,
                                            IdeGreeterSection     *section)
 {
+  const GList *windows;
+  GFile *info_file;
+
   IDE_ENTRY;
 
   g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
   g_assert (IDE_IS_PROJECT_INFO (project_info));
   g_assert (IDE_IS_GREETER_SECTION (section));
 
+  if (!(info_file = ide_project_info_get_file (project_info)))
+    goto load_project;
+
+  /* Look to see if we can find an already open project matching info */
+  windows = gtk_application_get_windows (GTK_APPLICATION (IDE_APPLICATION_DEFAULT));
+
+  for (const GList *iter = windows; iter != NULL; iter = iter->next)
+    {
+      GtkWindow *window = iter->data;
+      IdeContext *context;
+      GFile *project_file;
+
+      if (!IDE_IS_WORKBENCH (window))
+        continue;
+
+      if (!(context = ide_workbench_get_context (IDE_WORKBENCH (window))))
+        continue;
+
+      project_file = ide_context_get_project_file (context);
+
+      if (g_file_equal (project_file, info_file) ||
+          g_file_has_prefix (project_file, info_file) ||
+          g_file_has_prefix (info_file, project_file))
+        {
+          GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
+
+          gtk_window_present (window);
+          gtk_window_close (GTK_WINDOW (toplevel));
+
+          IDE_EXIT;
+        }
+    }
+
+load_project:
   ide_greeter_perspective_load_project (self, project_info);
 
   IDE_EXIT;
