@@ -35,6 +35,29 @@ static GList    *tasks;
 
 G_LOCK_DEFINE (lock);
 
+static gboolean
+strv_equal (gchar **a,
+            gchar **b)
+{
+  if (a == b)
+    return TRUE;
+  else if (!a && b)
+    return FALSE;
+  else if (a && !b)
+    return FALSE;
+
+  for (;;)
+    {
+      if (*a == NULL && *b == NULL)
+        return TRUE;
+
+      if (g_strcmp0 (*a, *b) == 0)
+        continue;
+
+      return FALSE;
+    }
+}
+
 static gboolean
 ide_language_defaults_migrate (GKeyFile  *key_file,
                                gint       current_version,
@@ -42,22 +65,22 @@ ide_language_defaults_migrate (GKeyFile  *key_file,
                                GError   **error)
 {
   gchar **groups;
-  gsize i;
+  gsize n_groups = 0;
 
   g_assert (key_file);
   g_assert (current_version >= 0);
   g_assert (current_version >= 0);
   g_assert (new_version > current_version);
 
-  groups = g_key_file_get_groups (key_file, NULL);
+  groups = g_key_file_get_groups (key_file, &n_groups);
 
-  for (i = 0; groups [i]; i++)
+  for (gsize i = 0; i < n_groups; i++)
     {
       const gchar *group = groups [i];
       g_autoptr(GSettings) settings = NULL;
       g_autofree gchar *lang_path = NULL;
       gchar **keys;
-      gsize j;
+      gsize n_keys = 0;
 
       g_assert (group != NULL);
 
@@ -65,15 +88,15 @@ ide_language_defaults_migrate (GKeyFile  *key_file,
         continue;
 
       lang_path = g_strdup_printf (PATH_BASE"%s/", group);
-      g_assert(lang_path);
+      g_assert (lang_path);
 
       settings = g_settings_new_with_path (SCHEMA_ID, lang_path);
       g_assert (G_IS_SETTINGS (settings));
 
-      keys = g_key_file_get_keys (key_file, group, NULL, NULL);
+      keys = g_key_file_get_keys (key_file, group, &n_keys, NULL);
       g_assert (keys);
 
-      for (j = 0; keys [j]; j++)
+      for (gsize j = 0; j < n_keys; j++)
         {
           const gchar *key = keys [j];
           g_autoptr(GVariant) default_value = NULL;
@@ -106,7 +129,7 @@ ide_language_defaults_migrate (GKeyFile  *key_file,
               current_str = g_settings_get_string (settings, key);
               override_str = g_key_file_get_string (key_file, group, key, NULL);
 
-              if (0 != g_strcmp0 (default_str, current_str))
+              if (g_strcmp0 (default_str, current_str) == 0)
                 g_settings_set_string (settings, key, override_str);
             }
           else if (g_variant_is_of_type (default_value, G_VARIANT_TYPE_BOOLEAN))
@@ -119,7 +142,7 @@ ide_language_defaults_migrate (GKeyFile  *key_file,
               current_bool = g_settings_get_boolean (settings, key);
               override_bool = g_key_file_get_boolean (key_file, group, key, NULL);
 
-              if (default_bool != current_bool)
+              if (default_bool == current_bool)
                 g_settings_set_boolean (settings, key, override_bool);
             }
           else if (g_variant_is_of_type (default_value, G_VARIANT_TYPE_INT32))
@@ -132,9 +155,22 @@ ide_language_defaults_migrate (GKeyFile  *key_file,
               current_int32 = g_settings_get_int (settings, key);
               override_int32 = g_key_file_get_integer (key_file, group, key, NULL);
 
-              if (default_int32 != current_int32)
+              if (default_int32 == current_int32)
                 g_settings_set_int (settings, key, override_int32);
             }
+          else if (g_variant_is_of_type (default_value, G_VARIANT_TYPE_STRING_ARRAY))
+            {
+              g_auto(GStrv) current_strv = NULL;
+              g_auto(GStrv) override_strv = NULL;
+              g_autofree const gchar **default_strv = NULL;
+
+              default_strv = g_variant_get_strv (default_value, NULL);
+              current_strv = g_settings_get_strv (settings, key);
+              override_strv = g_key_file_get_string_list (key_file, group, key, NULL, NULL);
+
+              if (strv_equal ((gchar **)default_strv, current_strv))
+                g_settings_set_strv (settings, key, (const gchar * const *)override_strv);
+            }
           else
             {
               g_error ("Teach me about variant type: %s",
@@ -238,16 +274,13 @@ ide_language_defaults_init_worker (GTask        *task,
   if (current_version < 0)
     {
       g_task_return_error (task, g_steal_pointer (&error));
-      goto failure;
+      IDE_GOTO (failure);
     }
 
+  IDE_TRACE_MSG ("Current language defaults at version %d", current_version);
+
   defaults = ide_language_defaults_get_defaults (&error);
-
-  if (!defaults)
-    {
-      g_task_return_error (task, g_steal_pointer (&error));
-      goto failure;
-    }
+  g_assert (defaults != NULL);
 
   key_file = g_key_file_new ();
   ret = g_key_file_load_from_data (key_file,
@@ -259,7 +292,7 @@ ide_language_defaults_init_worker (GTask        *task,
   if (!ret)
     {
       g_task_return_error (task, g_steal_pointer (&error));
-      goto failure;
+      IDE_GOTO (failure);
     }
 
   if (!g_key_file_has_group (key_file, "global") ||
@@ -269,7 +302,7 @@ ide_language_defaults_init_worker (GTask        *task,
                                G_IO_ERROR,
                                G_IO_ERROR_INVALID_DATA,
                                _("language defaults missing version in [global] group."));
-      goto failure;
+      IDE_GOTO (failure);
     }
 
   global_version = g_key_file_get_integer (key_file, "global", "version", &error);
@@ -277,7 +310,7 @@ ide_language_defaults_init_worker (GTask        *task,
   if (global_version == 0 && error != NULL)
     {
       g_task_return_error (task, g_steal_pointer (&error));
-      goto failure;
+      IDE_GOTO (failure);
     }
 
   g_clear_error (&error);
@@ -287,7 +320,7 @@ ide_language_defaults_init_worker (GTask        *task,
       if (!ide_language_defaults_migrate (key_file, current_version, global_version, &error))
         {
           g_task_return_error (task, g_steal_pointer (&error));
-          goto failure;
+          IDE_GOTO (failure);
         }
 
       version_contents = g_strdup_printf ("%d", global_version);
@@ -302,7 +335,7 @@ ide_language_defaults_init_worker (GTask        *task,
                                        G_IO_ERROR,
                                        g_io_error_from_errno (errno),
                                        "%s", g_strerror (errno));
-              goto failure;
+              IDE_GOTO (failure);
             }
         }
 
@@ -311,7 +344,7 @@ ide_language_defaults_init_worker (GTask        *task,
       if (!g_file_set_contents (version_path, version_contents, -1, &error))
         {
           g_task_return_error (task, g_steal_pointer (&error));
-          goto failure;
+          IDE_GOTO (failure);
         }
     }
 
