@@ -54,12 +54,13 @@
 #include "snippets/ide-source-snippets-manager.h"
 #include "testing/ide-test-manager.h"
 #include "transfers/ide-transfer-manager.h"
-#include "util/ide-async-helper.h"
-#include "util/ide-line-reader.h"
-#include "util/ide-settings.h"
 #include "vcs/ide-vcs.h"
 #include "vcs/ide-vcs-monitor.h"
 #include "workbench/ide-workbench.h"
+#include "util/ide-async-helper.h"
+#include "util/ide-glib.h"
+#include "util/ide-line-reader.h"
+#include "util/ide-settings.h"
 
 /**
  * SECTION:ide-context
@@ -1870,6 +1871,8 @@ ide_context_unload_buffer_manager (gpointer             source_object,
 
   buffers = ide_buffer_manager_get_buffers (self->buffer_manager);
 
+  IDE_PTR_ARRAY_SET_FREE_FUNC (buffers, g_object_unref);
+
   task = g_task_new (self, cancellable, callback, user_data);
 
   if (buffers->len == 0)
@@ -2230,6 +2233,7 @@ ide_context_restore_async (IdeContext          *self,
   self->restored = TRUE;
 
   ar = ide_unsaved_files_to_array (self->unsaved_files);
+  IDE_PTR_ARRAY_SET_FREE_FUNC (ar, ide_unsaved_file_unref);
 
   if (ar->len == 0)
     {
