@@ -52,6 +52,8 @@ IDE_AVAILABLE_IN_ALL
 IdeDocumentation         *ide_context_get_documentation         (IdeContext           *self);
 IDE_AVAILABLE_IN_ALL
 IdeProject               *ide_context_get_project               (IdeContext           *self);
+IDE_AVAILABLE_IN_3_28
+GSettings                *ide_context_get_project_settings      (IdeContext           *self);
 IDE_AVAILABLE_IN_ALL
 GtkRecentManager         *ide_context_get_recent_manager        (IdeContext           *self);
 IDE_AVAILABLE_IN_ALL
@@ -128,6 +130,10 @@ void                      ide_context_emit_log                  (IdeContext
                                                                  const gchar          *message,
                                                                  gssize                message_len);
 IDE_AVAILABLE_IN_3_28
+gchar                    *ide_context_build_filename            (IdeContext           *self,
+                                                                 const gchar          *first_part,
+                                                                 ...) G_GNUC_NULL_TERMINATED;
+IDE_AVAILABLE_IN_3_28
 GFile                    *ide_context_cache_file                (IdeContext           *self,
                                                                  const gchar          *first_part,
                                                                  ...) G_GNUC_NULL_TERMINATED;
@@ -138,6 +144,9 @@ gchar                    *ide_context_cache_filename            (IdeContext
 IDE_AVAILABLE_IN_3_28
 IdeVcsMonitor            *ide_context_get_monitor               (IdeContext           *self);
 
+IDE_AVAILABLE_IN_3_28
+gboolean                  ide_context_is_unloading              (IdeContext           *self);
+
 GListModel               *_ide_context_get_pausables            (IdeContext           *self) G_GNUC_INTERNAL;
 gboolean                  _ide_context_is_restoring             (IdeContext           *self) G_GNUC_INTERNAL;
 
