@@ -745,6 +745,9 @@ ide_object_notify_in_main_cb (gpointer data)
  * You may want to do this when modifying state from a thread, but only
  * notify from the Gtk+ thread.
  *
+ * This will *always* return to the default main context, and never
+ * emit ::notify immediately.
+ *
  * Since: 3.18
  */
 void
@@ -759,16 +762,6 @@ ide_object_notify_in_main (gpointer    instance,
   g_return_if_fail (G_IS_OBJECT (instance));
   g_return_if_fail (pspec != NULL);
 
-  /*
-   * Short circuit if we can notify immediately without the round trip
-   * to the main loop.
-   */
-  if G_LIKELY (g_main_context_get_thread_default () == g_main_context_default ())
-    {
-      g_object_notify_by_pspec (instance, pspec);
-      return;
-    }
-
   notify = g_slice_alloc0 (sizeof *notify);
   notify->object = g_object_ref (instance);
   notify->pspec = g_param_spec_ref (pspec);
@@ -823,3 +816,16 @@ ide_object_warning (gpointer     instance,
   else
     g_warning ("%s", str);
 }
+
+gboolean
+ide_object_is_unloading (IdeObject *object)
+{
+  IdeContext *context;
+
+  g_return_val_if_fail (IDE_IS_OBJECT (object), TRUE);
+
+  if (!(context = ide_object_get_context (object)))
+    return TRUE;
+
+  return ide_context_is_unloading (context);
+}
