@@ -37,6 +37,7 @@
 #include "langserv/ide-langserv-client.h"
 #include "projects/ide-project.h"
 #include "vcs/ide-vcs.h"
+#include "util/ide-glib.h"
 
 typedef struct
 {
@@ -570,7 +571,7 @@ ide_langserv_client_translate_diagnostics (IdeLangservClient *self,
       g_ptr_array_add (ar, g_steal_pointer (&diag));
     }
 
-  return ide_diagnostics_new (g_steal_pointer (&ar));
+  return ide_diagnostics_new (IDE_PTR_ARRAY_STEAL_FULL (&ar));
 }
 
 static void
