@@ -112,7 +112,8 @@ ide_langserv_highlighter_document_symbol_cb (GObject      *object,
 
   if (!ide_langserv_client_call_finish (client, result, &return_value, &error))
     {
-      g_message ("%s", error->message);
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_debug ("%s", error->message);
       IDE_EXIT;
     }
 
@@ -215,7 +216,7 @@ ide_langserv_highlighter_update_symbols (gpointer data)
 
       ide_langserv_client_call_async (priv->client,
                                       "textDocument/documentSymbol",
-                                      g_steal_pointer (&params),
+                                      params,
                                       NULL,
                                       ide_langserv_highlighter_document_symbol_cb,
                                       g_object_ref (self));
@@ -261,7 +262,7 @@ ide_langserv_highlighter_buffer_line_flags_changed (IdeLangservHighlighter *self
 }
 
 static void
-ide_langserv_highlighter_finalize (GObject *object)
+ide_langserv_highlighter_dispose (GObject *object)
 {
   IdeLangservHighlighter *self = (IdeLangservHighlighter *)object;
   IdeLangservHighlighterPrivate *priv = ide_langserv_highlighter_get_instance_private (self);
@@ -274,7 +275,7 @@ ide_langserv_highlighter_finalize (GObject *object)
   g_clear_object (&priv->buffer_signals);
   g_clear_object (&priv->client);
 
-  G_OBJECT_CLASS (ide_langserv_highlighter_parent_class)->finalize (object);
+  G_OBJECT_CLASS (ide_langserv_highlighter_parent_class)->dispose (object);
 }
 
 static void
@@ -320,7 +321,7 @@ ide_langserv_highlighter_class_init (IdeLangservHighlighterClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  object_class->finalize = ide_langserv_highlighter_finalize;
+  object_class->dispose = ide_langserv_highlighter_dispose;
   object_class->get_property = ide_langserv_highlighter_get_property;
   object_class->set_property = ide_langserv_highlighter_set_property;
 
