@@ -28,6 +28,7 @@
 #include "langserv/ide-langserv-client.h"
 #include "langserv/ide-langserv-rename-provider.h"
 #include "diagnostics/ide-source-location.h"
+#include "util/ide-glib.h"
 
 typedef struct
 {
@@ -326,20 +327,19 @@ ide_langserv_rename_provider_rename_finish (IdeRenameProvider  *provider,
                                             GPtrArray         **edits,
                                             GError            **error)
 {
-  IdeLangservRenameProvider *self = (IdeLangservRenameProvider *)provider;
   g_autoptr(GPtrArray) ar = NULL;
   gboolean ret;
 
   IDE_ENTRY;
 
-  g_assert (IDE_IS_LANGSERV_RENAME_PROVIDER (self));
+  g_assert (IDE_IS_LANGSERV_RENAME_PROVIDER (provider));
   g_assert (G_IS_TASK (result));
 
   ar = g_task_propagate_pointer (G_TASK (result), error);
   ret = (ar != NULL);
 
   if (edits != NULL)
-    *edits = g_steal_pointer (&ar);
+    *edits = IDE_PTR_ARRAY_STEAL_FULL (&ar);
 
   IDE_RETURN (ret);
 }
