@@ -30,6 +30,7 @@
 #include "langserv/ide-langserv-symbol-resolver.h"
 #include "langserv/ide-langserv-symbol-tree.h"
 #include "langserv/ide-langserv-symbol-tree-private.h"
+#include "util/ide-glib.h"
 
 typedef struct
 {
@@ -414,7 +415,7 @@ ide_langserv_symbol_resolver_document_symbol_cb (GObject      *object,
       g_ptr_array_add (symbols, g_steal_pointer (&symbol));
     }
 
-  tree = ide_langserv_symbol_tree_new (g_steal_pointer (&symbols));
+  tree = ide_langserv_symbol_tree_new (IDE_PTR_ARRAY_STEAL_FULL (&symbols));
 
   g_task_return_pointer (task, g_steal_pointer (&tree), g_object_unref);
 
@@ -658,6 +659,8 @@ ide_langserv_symbol_resolver_find_references_finish (IdeSymbolResolver  *self,
 
   ret = g_task_propagate_pointer (G_TASK (result), error);
 
+  IDE_PTR_ARRAY_CLEAR_FREE_FUNC (ret);
+
   IDE_RETURN (ret);
 }
 
