@@ -22,7 +22,9 @@
 #include <glib/gi18n.h>
 
 #include "ide-context.h"
+#include "ide-debug.h"
 
+#include "application/ide-application.h"
 #include "plugins/ide-extension-set-adapter.h"
 #include "plugins/ide-extension-util.h"
 
@@ -69,6 +71,7 @@ add_extension (IdeExtensionSetAdapter *self,
                PeasPluginInfo         *plugin_info,
                PeasExtension          *exten)
 {
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_assert (plugin_info != NULL);
   g_assert (exten != NULL);
@@ -83,15 +86,19 @@ remove_extension (IdeExtensionSetAdapter *self,
                   PeasPluginInfo         *plugin_info,
                   PeasExtension          *exten)
 {
+  g_autoptr(GObject) hold = NULL;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_assert (plugin_info != NULL);
   g_assert (exten != NULL);
-  g_assert (g_type_is_a (G_OBJECT_TYPE (exten), self->interface_type));
+  g_assert (self->interface_type == G_TYPE_INVALID ||
+            g_type_is_a (G_OBJECT_TYPE (exten), self->interface_type));
+
+  hold = g_object_ref (exten);
 
-  g_object_ref (exten);
   g_hash_table_remove (self->extensions, plugin_info);
-  g_signal_emit (self, signals [EXTENSION_REMOVED], 0, plugin_info, exten);
-  g_object_unref (exten);
+  g_signal_emit (self, signals [EXTENSION_REMOVED], 0, plugin_info, hold);
 }
 
 static void
@@ -99,6 +106,7 @@ ide_extension_set_adapter_enabled_changed (IdeExtensionSetAdapter *self,
                                            const gchar            *key,
                                            GSettings              *settings)
 {
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_assert (key != NULL);
   g_assert (G_IS_SETTINGS (settings));
@@ -114,6 +122,7 @@ watch_extension (IdeExtensionSetAdapter *self,
   GSettings *settings;
   gchar *path;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_assert (plugin_info != NULL);
   g_assert (G_TYPE_IS_INTERFACE (interface_type));
@@ -141,7 +150,9 @@ ide_extension_set_adapter_reload (IdeExtensionSetAdapter *self)
   IdeContext *context;
   const GList *plugins;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
+  g_assert (self->interface_type != G_TYPE_INVALID);
 
   while (self->settings->len > 0)
     {
@@ -164,6 +175,9 @@ ide_extension_set_adapter_reload (IdeExtensionSetAdapter *self)
       PeasPluginInfo *plugin_info = plugins->data;
       gint priority;
 
+      if (!peas_plugin_info_is_loaded (plugin_info))
+        continue;
+
       if (peas_engine_provides_extension (self->engine, plugin_info, self->interface_type))
         watch_extension (self, plugin_info, self->interface_type);
 
@@ -174,7 +188,7 @@ ide_extension_set_adapter_reload (IdeExtensionSetAdapter *self)
                                              self->value,
                                              &priority))
         {
-          if (!g_hash_table_lookup (self->extensions, plugin_info))
+          if (!g_hash_table_contains (self->extensions, plugin_info))
             {
               PeasExtension *exten;
 
@@ -210,6 +224,7 @@ ide_extension_set_adapter_reload (IdeExtensionSetAdapter *self)
             remove_extension (self, plugin_info, exten);
         }
     }
+
   g_signal_emit (self, signals [EXTENSIONS_LOADED], 0);
 }
 
@@ -218,10 +233,13 @@ ide_extension_set_adapter_do_reload (gpointer data)
 {
   IdeExtensionSetAdapter *self = data;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
 
   self->reload_handler = 0;
-  ide_extension_set_adapter_reload (self);
+
+  if (self->interface_type != G_TYPE_INVALID)
+    ide_extension_set_adapter_reload (self);
 
   return G_SOURCE_REMOVE;
 }
@@ -229,18 +247,22 @@ ide_extension_set_adapter_do_reload (gpointer data)
 static void
 ide_extension_set_adapter_queue_reload (IdeExtensionSetAdapter *self)
 {
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
 
-  if (self->reload_handler != 0)
-    return;
+  dzl_clear_source (&self->reload_handler);
 
-  self->reload_handler = g_timeout_add (0, ide_extension_set_adapter_do_reload, self);
+  self->reload_handler = g_idle_add_full (G_PRIORITY_HIGH,
+                                          ide_extension_set_adapter_do_reload,
+                                          self,
+                                          NULL);
 }
 
 static void
 ide_extension_set_adapter_set_engine (IdeExtensionSetAdapter *self,
                                       PeasEngine             *engine)
 {
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_assert (PEAS_IS_ENGINE (engine));
 
@@ -255,6 +277,7 @@ static void
 ide_extension_set_adapter_set_interface_type (IdeExtensionSetAdapter *self,
                                               GType                   interface_type)
 {
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_assert (G_TYPE_IS_INTERFACE (interface_type));
 
@@ -275,8 +298,12 @@ ide_extension_set_adapter_dispose (GObject *object)
   gpointer key;
   gpointer value;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (IDE_IS_EXTENSION_SET_ADAPTER (self));
 
+  self->interface_type = G_TYPE_INVALID;
+  dzl_clear_source (&self->reload_handler);
+
   /*
    * Steal the extensions so we can be re-entrant safe and not break
    * any assumptions about extensions being a real pointer.
@@ -498,6 +525,7 @@ void
 ide_extension_set_adapter_set_key (IdeExtensionSetAdapter *self,
                                    const gchar            *key)
 {
+  g_return_if_fail (IDE_IS_MAIN_THREAD ());
   g_return_if_fail (IDE_IS_EXTENSION_SET_ADAPTER (self));
 
   if (!dzl_str_equal0 (self->key, key))
@@ -512,6 +540,7 @@ ide_extension_set_adapter_set_key (IdeExtensionSetAdapter *self,
 const gchar *
 ide_extension_set_adapter_get_value (IdeExtensionSetAdapter *self)
 {
+  g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
   g_return_val_if_fail (IDE_IS_EXTENSION_SET_ADAPTER (self), NULL);
 
   return self->value;
@@ -521,8 +550,13 @@ void
 ide_extension_set_adapter_set_value (IdeExtensionSetAdapter *self,
                                      const gchar            *value)
 {
+  g_return_if_fail (IDE_IS_MAIN_THREAD ());
   g_return_if_fail (IDE_IS_EXTENSION_SET_ADAPTER (self));
 
+  IDE_TRACE_MSG ("Setting extension adapter %s value to \"%s\"",
+                 g_type_name (self->interface_type),
+                 value ?: "");
+
   if (!dzl_str_equal0 (self->value, value))
     {
       g_free (self->value);
@@ -549,6 +583,7 @@ ide_extension_set_adapter_foreach (IdeExtensionSetAdapter            *self,
   gpointer key;
   gpointer value;
 
+  g_return_if_fail (IDE_IS_MAIN_THREAD ());
   g_return_if_fail (IDE_IS_EXTENSION_SET_ADAPTER (self));
   g_return_if_fail (foreach_func != NULL);
 
@@ -581,6 +616,7 @@ ide_extension_set_adapter_new (IdeContext  *context,
                                const gchar *key,
                                const gchar *value)
 {
+  g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
   g_return_val_if_fail (IDE_IS_CONTEXT (context), NULL);
   g_return_val_if_fail (!engine || PEAS_IS_ENGINE (engine), NULL);
   g_return_val_if_fail (G_TYPE_IS_INTERFACE (interface_type), NULL);
@@ -608,6 +644,7 @@ PeasExtension *
 ide_extension_set_adapter_get_extension (IdeExtensionSetAdapter *self,
                                          PeasPluginInfo         *plugin_info)
 {
+  g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
   g_return_val_if_fail (IDE_IS_EXTENSION_SET_ADAPTER (self), NULL);
   g_return_val_if_fail (plugin_info != NULL, NULL);
 
