@@ -23,8 +23,10 @@
 #include "ide-context.h"
 #include "ide-debug.h"
 
+#include "application/ide-application.h"
+#include "buffers/ide-buffer.h"
+#include "buffers/ide-buffer-manager.h"
 #include "files/ide-file.h"
-#include "projects/ide-project-files.h"
 #include "projects/ide-project-item.h"
 #include "projects/ide-project.h"
 #include "subprocess/ide-subprocess.h"
@@ -44,8 +46,9 @@ struct _IdeProject
 
 typedef struct
 {
-  GFile *orig_file;
-  GFile *new_file;
+  GFile     *orig_file;
+  GFile     *new_file;
+  IdeBuffer *buffer;
 } RenameFile;
 
 G_DEFINE_TYPE (IdeProject, ide_project, IDE_TYPE_OBJECT)
@@ -198,154 +201,6 @@ ide_project_set_root (IdeProject     *self,
     g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ROOT]);
 }
 
-/**
- * ide_project_get_files:
- * @self: an #IdeProject.
- *
- * Gets the #IdeProjectFiles instance within the project tree.
- * If it has not yet been loaded, %NULL is returned.
- *
- * Returns: (transfer none) (nullable): An #IdeProjectFiles or %NULL.
- */
-IdeProjectFiles *
-ide_project_get_files (IdeProject *self)
-{
-  GSequenceIter *iter;
-  GSequence *children;
-  IdeProjectItem *root;
-
-  g_return_val_if_fail (IDE_IS_PROJECT (self), NULL);
-
-  root = ide_project_get_root (self);
-  children = ide_project_item_get_children (root);
-
-  if (children == NULL)
-    return NULL;
-
-  for (iter = g_sequence_get_begin_iter (children);
-       !g_sequence_iter_is_end (iter);
-       iter = g_sequence_iter_next (iter))
-    {
-      IdeProjectItem *item = g_sequence_get (iter);
-
-      if (IDE_IS_PROJECT_FILES (item))
-        return IDE_PROJECT_FILES (item);
-    }
-
-  return NULL;
-}
-
-/**
- * ide_project_get_file_for_path:
- * @path: A relative path from the project root.
- *
- * Retrieves an #IdeFile for the path specified. #IdeFile provides access to
- * language specific features via ide_file_get_language().
- *
- * You must hold the reader lock while calling this function. See
- * ide_project_reader_lock() and ide_project_reader_unlock() for more
- * information.
- *
- * Returns: (transfer full) (nullable): An #IdeFile or %NULL if no matching
- *   file could be found.
- */
-IdeFile *
-ide_project_get_file_for_path (IdeProject  *self,
-                               const gchar *path)
-{
-  IdeProjectFiles *files;
-  IdeFile *file = NULL;
-
-  g_return_val_if_fail (IDE_IS_PROJECT (self), NULL);
-  g_return_val_if_fail (path, NULL);
-
-  ide_project_reader_lock (self);
-
-  files = ide_project_get_files (self);
-  if (files != NULL)
-    file = ide_project_files_get_file_for_path (files, path);
-
-  ide_project_reader_unlock (self);
-
-  if (!file)
-    {
-      IdeContext *context;
-      IdeVcs *vcs;
-      GFile *workdir;
-      g_autoptr(GFile) gfile = NULL;
-
-      /*
-       * Okay, we couldn't find an existing item that matches this path, so let's
-       * synthesize one (but not add it to the tree). This could be hit in common
-       * cases like new files that are not yet added to the project.
-       */
-      context = ide_object_get_context (IDE_OBJECT (self));
-      g_assert (IDE_IS_CONTEXT (context));
-      vcs = ide_context_get_vcs (context);
-      workdir = ide_vcs_get_working_directory (vcs);
-      gfile = g_file_get_child (workdir, path);
-      file = g_object_new (IDE_TYPE_FILE,
-                           "context", context,
-                           "path", path,
-                           "file", gfile,
-                           NULL);
-    }
-
-  return file;
-}
-
-/**
- * ide_project_get_project_file:
- * @self: an #IdeProject.
- * @gfile: a #GFile.
- *
- * Gets a new #IdeFile representing @gfile.
- *
- * Returns: (transfer full): An #IdeFile.
- */
-IdeFile *
-ide_project_get_project_file (IdeProject *self,
-                              GFile      *gfile)
-{
-  g_autofree gchar *relpath = NULL;
-  IdeContext *context;
-  IdeVcs *vcs;
-  GFile *workdir;
-
-  g_return_val_if_fail (IDE_IS_PROJECT (self), NULL);
-  g_return_val_if_fail (G_IS_FILE (gfile), NULL);
-
-  context = ide_object_get_context (IDE_OBJECT (self));
-  vcs = ide_context_get_vcs (context);
-  workdir = ide_vcs_get_working_directory (vcs);
-
-  relpath = g_file_get_relative_path (workdir, gfile);
-  if (relpath)
-    return ide_project_get_file_for_path (self, relpath);
-
-  return g_object_new (IDE_TYPE_FILE,
-                       "context", context,
-                       "path", g_file_get_path (gfile),
-                       "file", gfile,
-                       NULL);
-}
-
-void
-ide_project_add_file (IdeProject     *self,
-                      IdeProjectFile *file)
-{
-  IdeProjectFiles *files;
-
-  g_return_if_fail (IDE_IS_PROJECT (self));
-  g_return_if_fail (IDE_IS_PROJECT_FILE (file));
-
-
-  ide_project_writer_lock (self);
-  files = ide_project_get_files (self);
-  ide_project_files_add_file (files, file);
-  ide_project_writer_unlock (self);
-}
-
 static void
 ide_project_finalize (GObject *object)
 {
@@ -464,10 +319,13 @@ rename_file_free (gpointer data)
 {
   RenameFile *op = data;
 
+  g_assert (IDE_IS_MAIN_THREAD ());
+
   if (op != NULL)
     {
       g_clear_object (&op->new_file);
       g_clear_object (&op->orig_file);
+      g_clear_object (&op->buffer);
       g_slice_free (RenameFile, op);
     }
 }
@@ -507,10 +365,10 @@ ide_project_rename_file_worker (GTask        *task,
   IdeProject *self = source_object;
   g_autofree gchar *path = NULL;
   g_autoptr(GFile) parent = NULL;
+  g_autoptr(GError) error = NULL;
+  RenameFile *op = task_data;
   IdeContext *context;
   IdeVcs *vcs;
-  RenameFile *op = task_data;
-  g_autoptr(GError) error = NULL;
   GFile *workdir;
 
   g_assert (IDE_IS_PROJECT (self));
@@ -570,6 +428,46 @@ ide_project_rename_file_worker (GTask        *task,
   g_task_return_boolean (task, TRUE);
 }
 
+static void
+ide_project_rename_buffer_save_cb (GObject      *object,
+                                   GAsyncResult *result,
+                                   gpointer      user_data)
+{
+  IdeBufferManager *bufmgr = (IdeBufferManager *)object;
+  g_autoptr(GTask) task = user_data;
+  g_autoptr(IdeFile) file = NULL;
+  g_autoptr(GError) error = NULL;
+  IdeContext *context;
+  RenameFile *rf;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (IDE_IS_BUFFER_MANAGER (bufmgr));
+  g_assert (G_IS_ASYNC_RESULT (result));
+  g_assert (G_IS_TASK (task));
+
+  if (!ide_buffer_manager_save_file_finish (bufmgr, result, &error))
+    {
+      g_task_return_error (task, g_steal_pointer (&error));
+      return;
+    }
+
+  rf = g_task_get_task_data (task);
+  g_assert (rf != NULL);
+  g_assert (G_IS_FILE (rf->orig_file));
+  g_assert (G_IS_FILE (rf->new_file));
+  g_assert (IDE_IS_BUFFER (rf->buffer));
+
+  /*
+   * Change the filename in the buffer so that the user doesn't continue
+   * to edit the file under the old name.
+   */
+  context = ide_object_get_context (IDE_OBJECT (bufmgr));
+  file = ide_file_new (context, rf->new_file);
+  ide_buffer_set_file (rf->buffer, file);
+
+  g_task_run_in_thread (task, ide_project_rename_file_worker);
+}
+
 void
 ide_project_rename_file_async (IdeProject          *self,
                                GFile               *orig_file,
@@ -579,6 +477,9 @@ ide_project_rename_file_async (IdeProject          *self,
                                gpointer             user_data)
 {
   g_autoptr(GTask) task = NULL;
+  IdeBufferManager *bufmgr;
+  IdeContext *context;
+  IdeBuffer *buffer;
   RenameFile *op;
 
   g_return_if_fail (IDE_IS_PROJECT (self));
@@ -586,12 +487,44 @@ ide_project_rename_file_async (IdeProject          *self,
   g_return_if_fail (G_IS_FILE (new_file));
   g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+  task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_source_tag (task, ide_project_rename_file_async);
+  g_task_set_priority (task, G_PRIORITY_LOW);
+
+  context = ide_object_get_context (IDE_OBJECT (self));
+  bufmgr = ide_context_get_buffer_manager (context);
+  buffer = ide_buffer_manager_find_buffer (bufmgr, orig_file);
+
   op = g_slice_new0 (RenameFile);
   op->orig_file = g_object_ref (orig_file);
   op->new_file = g_object_ref (new_file);
-
-  task = g_task_new (self, cancellable, callback, user_data);
+  op->buffer = buffer ? g_object_ref (buffer) : NULL;
   g_task_set_task_data (task, op, rename_file_free);
+
+  /*
+   * If the file is open and has any changes, we need to save those
+   * changes before we can proceed.
+   */
+  if (buffer != NULL)
+    {
+      g_autoptr(IdeFile) from = ide_file_new (context, orig_file);
+      g_autoptr(IdeFile) to = ide_file_new (context, new_file);
+
+      if (gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (buffer)))
+        {
+          ide_buffer_manager_save_file_async (bufmgr,
+                                              buffer,
+                                              from,
+                                              NULL,
+                                              NULL,
+                                              ide_project_rename_buffer_save_cb,
+                                              g_steal_pointer (&task));
+          return;
+        }
+
+      ide_buffer_set_file (buffer, to);
+    }
+
   g_task_run_in_thread (task, ide_project_rename_file_worker);
 }
 
