@@ -20,8 +20,11 @@
 
 #include <gtksourceview/gtksource.h>
 
+#include "ide-version-macros.h"
+
 G_BEGIN_DECLS
 
+IDE_AVAILABLE_IN_ALL
 gboolean ide_source_style_scheme_apply_style (GtkSourceStyleScheme *style_scheme,
                                               const gchar          *style,
                                               GtkTextTag           *tag);
