@@ -45,6 +45,7 @@ typedef struct
    */
   guint                 *target_column;
   IdeSourceViewMovement  type;                        /* Type of movement */
+  IdeSourceScrollAlign   scroll_align;                /* How to align the post-movement scroll */
   GtkTextIter            insert;                      /* Current insert cursor location */
   GtkTextIter            selection;                   /* Current selection cursor location */
   gint                   count;                       /* Repeat count for movement */
@@ -1857,7 +1858,8 @@ ide_source_view_movements_previous_match_modifier (Movement *mv)
 }
 
 static void
-ide_source_view_movement_match_search_char (Movement *mv, gboolean is_next_direction)
+ide_source_view_movement_match_search_char (Movement *mv,
+                                            gboolean  is_next_direction)
 {
   GtkTextIter insert;
   GtkTextIter limit;
@@ -1929,6 +1931,41 @@ ide_source_view_movement_match_search_char (Movement *mv, gboolean is_next_direc
     }
 }
 
+static void
+ide_source_view_movements_smart_home (Movement                  *mv,
+                                      GtkSourceSmartHomeEndType  mode)
+{
+  GtkTextIter iter;
+
+  g_assert (mv != NULL);
+
+  iter = mv->insert;
+
+  switch (mode)
+    {
+    case GTK_SOURCE_SMART_HOME_END_BEFORE:
+      ide_source_view_movements_first_nonspace_char (mv);
+      if (gtk_text_iter_equal (&iter, &mv->insert))
+        gtk_text_iter_set_line_offset (&mv->insert, 0);
+      return;
+
+    case GTK_SOURCE_SMART_HOME_END_AFTER:
+      ide_source_view_movements_first_char (mv);
+      if (gtk_text_iter_equal (&iter, &mv->insert))
+        ide_source_view_movements_first_nonspace_char (mv);
+      return;
+
+    case GTK_SOURCE_SMART_HOME_END_ALWAYS:
+      ide_source_view_movements_first_nonspace_char (mv);
+      return;
+
+    case GTK_SOURCE_SMART_HOME_END_DISABLED:
+    default:
+      ide_source_view_movements_first_char (mv);
+      return;
+    }
+}
+
 void
 _ide_source_view_apply_movement (IdeSourceView         *self,
                                  IdeSourceViewMovement  movement,
@@ -1993,6 +2030,7 @@ _ide_source_view_apply_movement (IdeSourceView         *self,
   mv.self = self;
   mv.target_column = target_column;
   mv.type = movement;
+  mv.scroll_align = IDE_SOURCE_SCROLL_BOTH;
   mv.extend_selection = extend_selection;
   mv.exclusive = exclusive;
   mv.count = count;
@@ -2031,23 +2069,27 @@ _ide_source_view_apply_movement (IdeSourceView         *self,
 
     case IDE_SOURCE_VIEW_MOVEMENT_FIRST_CHAR:
       mv.count = MAX (1, mv.count);
+      mv.scroll_align = IDE_SOURCE_SCROLL_X;
       ide_source_view_movements_first_char (&mv);
       xalign = 1.0;
       break;
 
     case IDE_SOURCE_VIEW_MOVEMENT_FIRST_NONSPACE_CHAR:
       mv.count = MAX (1, mv.count);
+      mv.scroll_align = IDE_SOURCE_SCROLL_X;
       ide_source_view_movements_first_nonspace_char (&mv);
       xalign = 1.0;
       break;
 
     case IDE_SOURCE_VIEW_MOVEMENT_MIDDLE_CHAR:
       mv.count = MAX (1, mv.count);
+      mv.scroll_align = IDE_SOURCE_SCROLL_X;
       ide_source_view_movements_middle_char (&mv);
       break;
 
     case IDE_SOURCE_VIEW_MOVEMENT_LAST_CHAR:
       mv.count = MAX (1, mv.count);
+      mv.scroll_align = IDE_SOURCE_SCROLL_X;
       ide_source_view_movements_last_char (&mv);
       break;
 
@@ -2227,6 +2269,7 @@ _ide_source_view_apply_movement (IdeSourceView         *self,
 
     case IDE_SOURCE_VIEW_MOVEMENT_LINE_END:
       mv.count = MAX (1, mv.count);
+      mv.scroll_align = IDE_SOURCE_SCROLL_X;
       ide_source_view_movements_line_end (&mv);
       break;
 
@@ -2322,6 +2365,18 @@ _ide_source_view_apply_movement (IdeSourceView         *self,
         ide_source_view_movement_match_search_char (&mv, TRUE);
       break;
 
+    case IDE_SOURCE_VIEW_MOVEMENT_SMART_HOME:
+      {
+        GtkSourceSmartHomeEndType smart_home;
+
+        mv.count = 1;
+        mv.scroll_align = IDE_SOURCE_SCROLL_X;
+
+        smart_home = gtk_source_view_get_smart_home_end (GTK_SOURCE_VIEW (self));
+        ide_source_view_movements_smart_home (&mv, smart_home);
+      }
+      break;
+
     default:
       g_return_if_reached ();
     }
@@ -2333,7 +2388,7 @@ _ide_source_view_apply_movement (IdeSourceView         *self,
     ide_source_view_get_visual_position (mv.self, &line, target_column);
 
   if (!mv.ignore_scroll_to_insert)
-    ide_source_view_scroll_mark_onscreen (self, insert, TRUE, xalign, 0.5);
+    ide_source_view_scroll_mark_onscreen (self, insert, mv.scroll_align, xalign, 0.5);
 
   /* Emit a jump if we moved more than JUMP_THRESHOLD lines */
   gtk_text_buffer_get_iter_at_mark (buffer, &after_insert, insert);
@@ -2552,7 +2607,7 @@ find_html_tag (GtkTextIter      *iter,
     }
 
   name = get_html_tag_name (&cursor);
-  if (ide_str_empty0 (name))
+  if (dzl_str_empty0 (name))
     {
       g_free (name);
       tag->kind = HTML_TAG_KIND_ERROR;
@@ -2632,7 +2687,7 @@ find_non_matching_html_tag_at_left (GtkTextIter *cursor,
           last_closing_tag = g_queue_peek_head (stack);
           if (last_closing_tag != NULL)
             {
-              if (ide_str_equal0 (tag->name, last_closing_tag->name))
+              if (dzl_str_equal0 (tag->name, last_closing_tag->name))
                 {
                   g_queue_pop_head (stack);
                   free_html_tag (last_closing_tag);
@@ -2690,7 +2745,7 @@ find_non_matching_html_tag_at_right (GtkTextIter *cursor,
         {
           while ((last_closing_tag = g_queue_pop_head (stack)))
             {
-              gboolean is_names_equal = ide_str_equal0 (tag->name, last_closing_tag->name);
+              gboolean is_names_equal = dzl_str_equal0 (tag->name, last_closing_tag->name);
 
               free_html_tag (last_closing_tag);
               if (is_names_equal)
@@ -2741,7 +2796,7 @@ get_html_element (GtkTextIter cursor_left,
     {
       while ((left_tag = find_non_matching_html_tag_at_left (&cursor_left, block_cursor)))
         {
-          if (!ide_str_equal0 (left_tag->name, right_tag->name))
+          if (!dzl_str_equal0 (left_tag->name, right_tag->name))
             {
               cursor_left = left_tag->begin;
               free_html_tag (left_tag);
