@@ -18,20 +18,14 @@
 
 #define G_LOG_DOMAIN "ide-code-index-entries"
 
+#include "application/ide-application.h"
 #include "symbols/ide-code-index-entries.h"
 
 G_DEFINE_INTERFACE (IdeCodeIndexEntries, ide_code_index_entries, G_TYPE_OBJECT)
 
-IdeCodeIndexEntry *
-ide_code_index_entries_real_get_next_entry (IdeCodeIndexEntries *self)
-{
-  return NULL;
-}
-
 static void
 ide_code_index_entries_default_init (IdeCodeIndexEntriesInterface *iface)
 {
-  iface->get_next_entry = ide_code_index_entries_real_get_next_entry;
 }
 
 /**
@@ -49,7 +43,25 @@ ide_code_index_entries_default_init (IdeCodeIndexEntriesInterface *iface)
 IdeCodeIndexEntry *
 ide_code_index_entries_get_next_entry (IdeCodeIndexEntries *self)
 {
+  g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
   g_return_val_if_fail (IDE_IS_CODE_INDEX_ENTRIES (self), NULL);
 
   return IDE_CODE_INDEX_ENTRIES_GET_IFACE (self)->get_next_entry (self);
 }
+
+/**
+ * ide_code_index_entries_get_file:
+ * @self: a #IdeCodeIndexEntries
+ *
+ * The file that was indexed.
+ *
+ * Returns: (transfer full): a #GFile
+ */
+GFile *
+ide_code_index_entries_get_file (IdeCodeIndexEntries *self)
+{
+  g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
+  g_return_val_if_fail (IDE_IS_CODE_INDEX_ENTRIES (self), NULL);
+
+  return IDE_CODE_INDEX_ENTRIES_GET_IFACE (self)->get_file (self);
+}
