@@ -21,6 +21,7 @@
 #include <glib-object.h>
 
 #include "ide.h"
+#include "gb-beautifier-editor-addin.h"
 
 G_BEGIN_DECLS
 
@@ -33,7 +34,11 @@ struct _GbBeautifierEditorAddin
   IdeLayoutView         *current_view;
   GArray                *entries;
 
+  gchar                 *tmp_dir;
+
   gboolean               has_default;
 };
 
+GbBeautifierEditorAddin    *gb_beautifier_editor_addin_get_editor_perspective    (GbBeautifierEditorAddin *self);
+
 G_END_DECLS
