@@ -22,6 +22,7 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#include "ide-clang-private.h"
 #include "ide-clang-symbol-node.h"
 
 struct _IdeClangSymbolNode
@@ -128,16 +129,18 @@ get_symbol_kind (CXCursor        cursor,
   return kind;
 }
 
-IdeClangSymbolNode *
+IdeSymbolNode *
 _ide_clang_symbol_node_new (IdeContext *context,
                             CXCursor    cursor)
 {
   IdeClangSymbolNode *self;
   IdeSymbolFlags flags = 0;
   IdeSymbolKind kind;
-  CXString cxname;
+  g_auto(CXString) cxname = {0};
   const gchar *name;
 
+  g_assert (IDE_IS_CONTEXT (context));
+
   kind = get_symbol_kind (cursor, &flags);
   cxname = clang_getCursorSpelling (cursor);
   name = clang_getCString (cxname);
@@ -151,9 +154,7 @@ _ide_clang_symbol_node_new (IdeContext *context,
 
   self->cursor = cursor;
 
-  clang_disposeString (cxname);
-
-  return self;
+  return IDE_SYMBOL_NODE (self);
 }
 
 CXCursor
@@ -171,22 +172,22 @@ ide_clang_symbol_node_get_location_async (IdeSymbolNode       *symbol_node,
                                           gpointer             user_data)
 {
   IdeClangSymbolNode *self = (IdeClangSymbolNode *)symbol_node;
-  IdeSourceLocation *ret;
+  g_autoptr(IdeFile) ifile = NULL;
+  g_autoptr(GFile) gfile = NULL;
+  g_autoptr(GTask) task = NULL;
+  g_auto(CXString) cxfilename = {0};
   IdeContext *context;
   const gchar *filename;
-  CXString cxfilename;
   CXSourceLocation cxloc;
   CXFile file;
-  GFile *gfile;
-  IdeFile *ifile;
   guint line = 0;
   guint line_offset = 0;
-  g_autoptr(GTask) task = NULL;
 
   g_return_if_fail (IDE_IS_CLANG_SYMBOL_NODE (self));
 
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, ide_clang_symbol_node_get_location_async);
+  g_task_set_priority (task, G_PRIORITY_LOW);
 
   cxloc = clang_getCursorLocation (self->cursor);
   clang_getFileLocation (cxloc, &file, &line, &line_offset, NULL);
@@ -199,18 +200,11 @@ ide_clang_symbol_node_get_location_async (IdeSymbolNode       *symbol_node,
 
   context = ide_object_get_context (IDE_OBJECT (self));
   gfile = g_file_new_for_path (filename);
-  ifile = g_object_new (IDE_TYPE_FILE,
-                        "file", gfile,
-                        "context", context,
-                        NULL);
+  ifile = ide_file_new (context, gfile);
 
-  ret = ide_source_location_new (ifile, line-1, line_offset-1, 0);
-
-  g_clear_object (&ifile);
-  g_clear_object (&gfile);
-  clang_disposeString (cxfilename);
-
-  g_task_return_pointer (task, ret, (GDestroyNotify)ide_source_location_unref);
+  g_task_return_pointer (task,
+                         ide_source_location_new (ifile, line-1, line_offset-1, 0),
+                         (GDestroyNotify)ide_source_location_unref);
 }
 
 static IdeSourceLocation *
@@ -224,10 +218,23 @@ ide_clang_symbol_node_get_location_finish (IdeSymbolNode  *symbol_node,
   return g_task_propagate_pointer (G_TASK (result), error);
 }
 
+static void
+ide_clang_symbol_node_finalize (GObject *object)
+{
+  IdeClangSymbolNode *self = (IdeClangSymbolNode *)object;
+
+  g_clear_pointer (&self->children, g_array_unref);
+
+  G_OBJECT_CLASS (ide_clang_symbol_node_parent_class)->finalize (object);
+}
+
 static void
 ide_clang_symbol_node_class_init (IdeClangSymbolNodeClass *klass)
 {
   IdeSymbolNodeClass *node_class = IDE_SYMBOL_NODE_CLASS (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  object_class->finalize = ide_clang_symbol_node_finalize;
 
   node_class->get_location_async = ide_clang_symbol_node_get_location_async;
   node_class->get_location_finish = ide_clang_symbol_node_get_location_finish;
