@@ -681,12 +681,14 @@ get_changes_worker (GTask        *task,
    */
   to_update = g_ptr_array_new_with_free_func (g_object_unref);
 
+  if (g_task_return_error_if_cancelled (task))
+    return;
+
   /*
    * Process directories to check for changes, while ensuring we have not
    * been asynchronously cancelled.
    */
-  while (!g_task_return_error_if_cancelled (task) &&
-         !g_queue_is_empty (&gcd->directories))
+  while (!g_queue_is_empty (&gcd->directories))
     {
       g_autofree gchar *relative = NULL;
       g_autoptr(GFile) dir = g_queue_pop_head (&gcd->directories);
@@ -715,6 +717,9 @@ get_changes_worker (GTask        *task,
         g_ptr_array_add (to_update, g_steal_pointer (&dir));
 
       g_queue_foreach (&files, (GFunc)file_info_free, NULL);
+
+      if (g_task_return_error_if_cancelled (task))
+        return;
     }
 
   /* In case we were cancelled */
@@ -1155,6 +1160,8 @@ index_directory_async (IdeCodeIndexBuilder *self,
 
   g_hash_table_iter_init (&iter, build_flags);
 
+  idd->n_active++;
+
   while (g_hash_table_iter_next (&iter, &k, &v))
     {
       IdeFile *file = k;
@@ -1180,6 +1187,8 @@ index_directory_async (IdeCodeIndexBuilder *self,
         }
     }
 
+  idd->n_active--;
+
   if (idd->n_active == 0)
     g_task_return_boolean (task, TRUE);
 }
@@ -1357,6 +1366,7 @@ build_get_changes_cb (GObject      *object,
 
   bd = g_task_get_task_data (task);
   g_assert (bd != NULL);
+  g_assert (bd->magic == BUILD_DATA_MAGIC);
   g_assert (G_IS_FILE (bd->data_dir));
   g_assert (G_IS_FILE (bd->index_dir));
   g_assert (bd->changes == NULL);
