@@ -127,7 +127,7 @@ collect_tag_names (GtkTextTag *tag,
   g_assert (taglist != NULL);
 
   g_object_get (G_OBJECT (tag), "name", &name, NULL);
-  if (!ide_str_empty0 (name) && g_str_has_prefix (name, COLOR_TAG_PREFIX))
+  if (!dzl_str_empty0 (name) && g_str_has_prefix (name, COLOR_TAG_PREFIX))
     g_ptr_array_add (taglist, g_steal_pointer (&name));
 }
 
@@ -332,7 +332,7 @@ remove_tag_cb (GbColorPickerDocumentMonitor *self,
   tag_table = gtk_text_buffer_get_tag_table (GTK_TEXT_BUFFER (self->buffer));
   g_object_get (G_OBJECT (tag), "name", &name, NULL);
 
-  if (!ide_str_empty0 (name) &&
+  if (!dzl_str_empty0 (name) &&
       g_str_has_prefix (name, COLOR_TAG_PREFIX) &&
       gtk_text_tag_table_lookup (tag_table, name))
     gtk_text_tag_table_remove (tag_table, tag);
@@ -514,7 +514,7 @@ gb_color_picker_document_monitor_set_buffer (GbColorPickerDocumentMonitor *self,
   if (self->buffer != buffer && self->buffer != NULL)
     stop_monitor (self);
 
-  if (ide_set_weak_pointer (&self->buffer, buffer))
+  if (dzl_set_weak_pointer (&self->buffer, buffer))
     {
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_BUFFER]);
 
@@ -544,7 +544,7 @@ gb_color_picker_document_monitor_finalize (GObject *object)
 {
   GbColorPickerDocumentMonitor *self = (GbColorPickerDocumentMonitor *)object;
 
-  ide_clear_weak_pointer (&self->buffer);
+  dzl_clear_weak_pointer (&self->buffer);
 
   G_OBJECT_CLASS (gb_color_picker_document_monitor_parent_class)->finalize (object);
 }
@@ -703,7 +703,7 @@ gb_color_picker_document_monitor_queue_oper (GbColorPickerDocumentMonitor *self,
     real_end = *end;
 
   queued.self = g_object_ref (self);
-  queued.buffer = g_object_ref (self->buffer);
+  queued.buffer = g_object_ref (buffer);
   queued.begin = g_object_ref (gtk_text_buffer_create_mark (buffer, NULL, &real_begin, TRUE));
   queued.end = g_object_ref (gtk_text_buffer_create_mark (buffer, NULL, &real_end, FALSE));
   queued.uncolorize = !!uncolorize;
