@@ -30,8 +30,10 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (IdeCtagsCompletionItem, ide_ctags_completion_item, IDE, CTAGS_COMPLETION_ITEM, IdeCompletionItem)
 
-IdeCtagsCompletionItem *
-ide_ctags_completion_item_new (IdeCtagsCompletionProvider *provider,
-                               const IdeCtagsIndexEntry   *entry);
+IdeCtagsCompletionItem *ide_ctags_completion_item_new         (IdeCtagsCompletionProvider *provider,
+                                                               const IdeCtagsIndexEntry   *entry);
+gboolean                ide_ctags_completion_item_is_function (IdeCtagsCompletionItem     *self);
+IdeSourceSnippet       *ide_ctags_completion_item_get_snippet (IdeCtagsCompletionItem     *self,
+                                                               IdeFileSettings            *file_settings);
 
 G_END_DECLS
