@@ -85,6 +85,9 @@ get_tag_from_kind (IdeCtagsIndexEntryKind kind)
     case IDE_CTAGS_INDEX_ENTRY_STRUCTURE:
       return IDE_CTAGS_HIGHLIGHTER_TYPE;
 
+    case IDE_CTAGS_INDEX_ENTRY_IMPORT:
+      return IDE_CTAGS_HIGHLIGHTER_IMPORT;
+
     case IDE_CTAGS_INDEX_ENTRY_ANCHOR:
     case IDE_CTAGS_INDEX_ENTRY_CLASS_NAME:
     case IDE_CTAGS_INDEX_ENTRY_DEFINE:
