@@ -22,9 +22,11 @@
 #include <libpeas/peas.h>
 
 #include "gbp-deviced-device-provider.h"
+#include "gbp-deviced-deploy-strategy.h"
 
 void
 gbp_deviced_register_types (PeasObjectModule *module)
 {
   peas_object_module_register_extension_type (module, IDE_TYPE_DEVICE_PROVIDER, GBP_TYPE_DEVICED_DEVICE_PROVIDER);
+  peas_object_module_register_extension_type (module, IDE_TYPE_DEPLOY_STRATEGY, GBP_TYPE_DEVICED_DEPLOY_STRATEGY);
 }
