@@ -53,8 +53,11 @@ enum {
 };
 
 enum {
-  EXPORT_BUILD_FINISH,
-  EXPORT_BUILD_EXPORT,
+  COMMIT_BUILD_FINISH,
+  COMMIT_BUILD_EXPORT,
+};
+
+enum {
   EXPORT_BUILD_BUNDLE,
 };
 
@@ -135,7 +138,6 @@ register_mkdirs_stage (GbpFlatpakPipelineAddin  *self,
                        GError                  **error)
 {
   g_autoptr(IdeBuildStage) mkdirs = NULL;
-  IdeConfiguration *config;
   g_autofree gchar *repo_dir = NULL;
   g_autofree gchar *staging_dir = NULL;
   guint stage_id;
@@ -144,13 +146,11 @@ register_mkdirs_stage (GbpFlatpakPipelineAddin  *self,
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
   g_assert (IDE_IS_CONTEXT (context));
 
-  config = ide_build_pipeline_get_configuration (pipeline);
-
   mkdirs = ide_build_stage_mkdirs_new (context);
   ide_build_stage_set_name (mkdirs, _("Creating flatpak workspace"));
 
-  repo_dir = gbp_flatpak_get_repo_dir (config);
-  staging_dir = gbp_flatpak_get_staging_dir (config);
+  repo_dir = gbp_flatpak_get_repo_dir (context);
+  staging_dir = gbp_flatpak_get_staging_dir (pipeline);
 
   ide_build_stage_mkdirs_add_path (IDE_BUILD_STAGE_MKDIRS (mkdirs), repo_dir, TRUE, 0750, FALSE);
   ide_build_stage_mkdirs_add_path (IDE_BUILD_STAGE_MKDIRS (mkdirs), staging_dir, TRUE, 0750, TRUE);
@@ -163,25 +163,92 @@ register_mkdirs_stage (GbpFlatpakPipelineAddin  *self,
 }
 
 static void
-check_if_file_exists (IdeBuildStage    *stage,
-                      IdeBuildPipeline *pipeline,
-                      GCancellable     *cancellable,
-                      const gchar      *file_path)
+reap_staging_dir_cb (GObject      *object,
+                     GAsyncResult *result,
+                     gpointer      user_data)
 {
-  gboolean exists;
+  DzlDirectoryReaper *reaper = (DzlDirectoryReaper *)object;
+  g_autoptr(IdeBuildStage) stage = user_data;
+  g_autoptr(GError) error = NULL;
+
+  IDE_ENTRY;
+
+  g_assert (DZL_IS_DIRECTORY_REAPER (reaper));
+  g_assert (G_IS_ASYNC_RESULT (result));
+  g_assert (IDE_IS_BUILD_STAGE (stage));
+
+  if (!dzl_directory_reaper_execute_finish (reaper, result, &error))
+    ide_object_warning (stage,
+                        "Failed to reap staging directory: %s",
+                        error->message);
+
+  ide_build_stage_unpause (stage);
+
+  IDE_EXIT;
+}
+
+static void
+check_for_build_init_files (IdeBuildStage    *stage,
+                            IdeBuildPipeline *pipeline,
+                            GCancellable     *cancellable,
+                            const gchar      *staging_dir)
+{
+  g_autofree gchar *metadata = NULL;
+  g_autofree gchar *files = NULL;
+  g_autofree gchar *var = NULL;
+  gboolean completed = FALSE;
+  gboolean parent_exists;
 
   g_assert (IDE_IS_BUILD_STAGE (stage));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
-  g_assert (file_path != NULL);
+  g_assert (staging_dir != NULL);
 
-  exists = g_file_test (file_path, G_FILE_TEST_IS_REGULAR);
+  metadata = g_build_filename (staging_dir, "metadata", NULL);
+  files = g_build_filename (staging_dir, "files", NULL);
+  var = g_build_filename (staging_dir, "var", NULL);
 
-  IDE_TRACE_MSG ("%s::query checking for %s: %s",
-                 G_OBJECT_TYPE_NAME (stage),
-                 file_path,
-                 exists ? "yes" : "no");
+  parent_exists = g_file_test (staging_dir, G_FILE_TEST_IS_DIR);
 
-  ide_build_stage_set_completed (stage, exists);
+  if (parent_exists &&
+      g_file_test (metadata, G_FILE_TEST_IS_REGULAR) &&
+      g_file_test (files, G_FILE_TEST_IS_DIR) &&
+      g_file_test (var, G_FILE_TEST_IS_DIR))
+    completed = TRUE;
+
+  IDE_TRACE_MSG ("Checking for previous build-init in %s: %s",
+                 staging_dir, completed ? "yes" : "no");
+
+  ide_build_stage_set_completed (stage, completed);
+
+  if (!completed && parent_exists)
+    {
+      g_autoptr(DzlDirectoryReaper) reaper = NULL;
+      g_autoptr(GFile) staging = g_file_new_for_path (staging_dir);
+
+      ide_build_stage_pause (stage);
+
+      reaper = dzl_directory_reaper_new ();
+      dzl_directory_reaper_add_directory (reaper, staging, 0);
+      dzl_directory_reaper_execute_async (reaper,
+                                          cancellable,
+                                          reap_staging_dir_cb,
+                                          g_object_ref (stage));
+    }
+}
+
+static void
+reap_staging_dir (IdeBuildStage      *stage,
+                  DzlDirectoryReaper *reaper,
+                  const gchar        *staging_dir)
+{
+  g_autoptr(GFile) dir = NULL;
+
+  g_assert (IDE_IS_BUILD_STAGE (stage));
+  g_assert (DZL_IS_DIRECTORY_REAPER (reaper));
+  g_assert (staging_dir != NULL);
+
+  dir = g_file_new_for_path (staging_dir);
+  dzl_directory_reaper_add_directory (reaper, dir, 0);
 }
 
 static gboolean
@@ -194,7 +261,6 @@ register_build_init_stage (GbpFlatpakPipelineAddin  *self,
   g_autoptr(IdeBuildStage) stage = NULL;
   g_autofree gchar *staging_dir = NULL;
   g_autofree gchar *sdk = NULL;
-  g_autofree gchar *metadata_path = NULL;
   g_autofree gchar *arch = NULL;
   IdeConfiguration *config;
   IdeRuntime *runtime;
@@ -222,7 +288,7 @@ register_build_init_stage (GbpFlatpakPipelineAddin  *self,
     }
 
   arch = get_arch_option (pipeline);
-  staging_dir = gbp_flatpak_get_staging_dir (config);
+  staging_dir = gbp_flatpak_get_staging_dir (pipeline);
   app_id = ide_configuration_get_app_id (config);
   platform = gbp_flatpak_runtime_get_platform (GBP_FLATPAK_RUNTIME (runtime));
   sdk = gbp_flatpak_runtime_get_sdk_name (GBP_FLATPAK_RUNTIME (runtime));
@@ -250,8 +316,6 @@ register_build_init_stage (GbpFlatpakPipelineAddin  *self,
   if (sdk == NULL)
     sdk = g_strdup (platform);
 
-  metadata_path = g_build_filename (staging_dir, "metadata", NULL);
-
   ide_subprocess_launcher_push_argv (launcher, "flatpak");
   ide_subprocess_launcher_push_argv (launcher, "build-init");
   ide_subprocess_launcher_push_argv (launcher, arch);
@@ -274,8 +338,19 @@ register_build_init_stage (GbpFlatpakPipelineAddin  *self,
    */
   g_signal_connect_data (stage,
                          "query",
-                         G_CALLBACK (check_if_file_exists),
-                         g_steal_pointer (&metadata_path),
+                         G_CALLBACK (check_for_build_init_files),
+                         g_strdup (staging_dir),
+                         (GClosureNotify)g_free,
+                         0);
+
+  /*
+   * When reaping the build, during a rebuild, make sure we wipe
+   * out the stagint directory too.
+   */
+  g_signal_connect_data (stage,
+                         "reap",
+                         G_CALLBACK (reap_staging_dir),
+                         g_strdup (staging_dir),
                          (GClosureNotify)g_free,
                          0);
 
@@ -345,7 +420,7 @@ register_dependencies_stage (GbpFlatpakPipelineAddin  *self,
   primary_module = gbp_flatpak_manifest_get_primary_module (GBP_FLATPAK_MANIFEST (config));
   manifest_path = gbp_flatpak_manifest_get_path (GBP_FLATPAK_MANIFEST (config));
 
-  staging_dir = gbp_flatpak_get_staging_dir (config);
+  staging_dir = gbp_flatpak_get_staging_dir (pipeline);
   src_dir = ide_build_pipeline_get_srcdir (pipeline);
 
   launcher = create_subprocess_launcher ();
@@ -417,7 +492,7 @@ register_build_finish_stage (GbpFlatpakPipelineAddin  *self,
 
   command = gbp_flatpak_manifest_get_command (GBP_FLATPAK_MANIFEST (config));
   finish_args = gbp_flatpak_manifest_get_finish_args (GBP_FLATPAK_MANIFEST (config));
-  staging_dir = gbp_flatpak_get_staging_dir (config);
+  staging_dir = gbp_flatpak_get_staging_dir (pipeline);
 
   launcher = create_subprocess_launcher ();
 
@@ -439,7 +514,7 @@ register_build_finish_stage (GbpFlatpakPipelineAddin  *self,
                         "launcher", launcher,
                         NULL);
 
-  stage_id = ide_build_pipeline_connect (pipeline, IDE_BUILD_PHASE_EXPORT, EXPORT_BUILD_FINISH, stage);
+  stage_id = ide_build_pipeline_connect (pipeline, IDE_BUILD_PHASE_COMMIT, COMMIT_BUILD_FINISH, stage);
   ide_build_pipeline_addin_track (IDE_BUILD_PIPELINE_ADDIN (self), stage_id);
 
   return TRUE;
@@ -467,8 +542,8 @@ register_build_export_stage (GbpFlatpakPipelineAddin  *self,
   if (!GBP_IS_FLATPAK_MANIFEST (config))
     return TRUE;
 
-  staging_dir = gbp_flatpak_get_staging_dir (config);
-  repo_dir = gbp_flatpak_get_repo_dir (config);
+  staging_dir = gbp_flatpak_get_staging_dir (pipeline);
+  repo_dir = gbp_flatpak_get_repo_dir (context);
   arch = get_arch_option (pipeline);
 
   launcher = create_subprocess_launcher ();
@@ -490,7 +565,7 @@ register_build_export_stage (GbpFlatpakPipelineAddin  *self,
                     G_CALLBACK (always_run_query_handler),
                     NULL);
 
-  stage_id = ide_build_pipeline_connect (pipeline, IDE_BUILD_PHASE_EXPORT, EXPORT_BUILD_EXPORT, stage);
+  stage_id = ide_build_pipeline_connect (pipeline, IDE_BUILD_PHASE_COMMIT, COMMIT_BUILD_EXPORT, stage);
   ide_build_pipeline_addin_track (IDE_BUILD_PIPELINE_ADDIN (self), stage_id);
 
   return TRUE;
@@ -542,8 +617,8 @@ register_build_bundle_stage (GbpFlatpakPipelineAddin  *self,
   if (!GBP_IS_FLATPAK_MANIFEST (config))
     return TRUE;
 
-  staging_dir = gbp_flatpak_get_staging_dir (config);
-  repo_dir = gbp_flatpak_get_repo_dir (config);
+  staging_dir = gbp_flatpak_get_staging_dir (pipeline);
+  repo_dir = gbp_flatpak_get_repo_dir (context);
 
   app_id = ide_configuration_get_app_id (config);
   name = g_strdup_printf ("%s.flatpak", app_id);
