@@ -1138,10 +1138,14 @@ gbp_gdb_debugger_list_breakpoints_finish (IdeDebugger   *debugger,
                                           GAsyncResult  *result,
                                           GError       **error)
 {
+  GPtrArray *ret;
+
   g_assert (GBP_IS_GDB_DEBUGGER (debugger));
   g_assert (G_IS_TASK (result));
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  ret = g_task_propagate_pointer (G_TASK (result), error);
+
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 static void
@@ -1634,10 +1638,14 @@ gbp_gdb_debugger_list_frames_finish (IdeDebugger   *debugger,
                                      GAsyncResult  *result,
                                      GError       **error)
 {
+  GPtrArray *ret;
+
   g_assert (GBP_IS_GDB_DEBUGGER (debugger));
   g_assert (G_IS_TASK (result));
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  ret = g_task_propagate_pointer (G_TASK (result), error);
+
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 static void
@@ -1980,10 +1988,14 @@ gbp_gdb_debugger_list_locals_finish (IdeDebugger   *debugger,
                                      GAsyncResult  *result,
                                      GError       **error)
 {
+  GPtrArray *ret;
+
   g_assert (GBP_IS_GDB_DEBUGGER (debugger));
   g_assert (G_IS_TASK (result));
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  ret = g_task_propagate_pointer (G_TASK (result), error);
+
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 static void
@@ -2105,10 +2117,14 @@ gbp_gdb_debugger_list_params_finish (IdeDebugger   *debugger,
                                      GAsyncResult  *result,
                                      GError       **error)
 {
+  GPtrArray *ret;
+
   g_assert (GBP_IS_GDB_DEBUGGER (debugger));
   g_assert (G_IS_TASK (result));
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  ret = g_task_propagate_pointer (G_TASK (result), error);
+
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 static void
@@ -2212,10 +2228,14 @@ gbp_gdb_debugger_list_registers_finish (IdeDebugger   *debugger,
                                         GAsyncResult  *result,
                                         GError       **error)
 {
+  GPtrArray *ret;
+
   g_assert (GBP_IS_GDB_DEBUGGER (debugger));
   g_assert (G_IS_TASK (result));
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  ret = g_task_propagate_pointer (G_TASK (result), error);
+
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 static void
@@ -2328,10 +2348,14 @@ gbp_gdb_debugger_disassemble_finish (IdeDebugger   *debugger,
                                      GAsyncResult  *result,
                                      GError       **error)
 {
+  GPtrArray *ret;
+
   g_assert (GBP_IS_GDB_DEBUGGER (debugger));
   g_assert (G_IS_TASK (result));
 
-  return g_task_propagate_pointer (G_TASK (result), error);
+  ret = g_task_propagate_pointer (G_TASK (result), error);
+
+  return IDE_PTR_ARRAY_STEAL_FULL (&ret);
 }
 
 static gboolean
@@ -2738,7 +2762,6 @@ gbp_gdb_debugger_exec_async (GbpGdbDebugger      *self,
   g_autoptr(GTask) task = NULL;
   g_autoptr(GError) error = NULL;
   g_autoptr(GBytes) bytes = NULL;
-  IdeDebuggerThread *selected;
   GOutputStream *stream;
   GString *str;
   guint id;
@@ -2771,18 +2794,13 @@ gbp_gdb_debugger_exec_async (GbpGdbDebugger      *self,
 
   str = g_string_new (NULL);
 
-  selected = ide_debugger_get_selected_thread (IDE_DEBUGGER (self));
-
   /* We might need to switch threads before we execute the command. */
   if (thread != NULL)
     {
-      if (selected == NULL || ide_debugger_thread_compare (selected, thread) != 0)
-        {
-          const gchar *tid = ide_debugger_thread_get_id (thread);
+      const gchar *tid = ide_debugger_thread_get_id (thread);
 
-          /* We ignore 9999 commands */
-          g_string_append_printf (str, "9999-thread-select %s\n", tid);
-        }
+      /* We ignore 9999 commands */
+      g_string_append_printf (str, "9999-thread-select %s\n", tid);
     }
 
   if (command[0] == '-' || strstr (command, "@@@@") != NULL)
