@@ -72,6 +72,7 @@ new_terminal_activate (GSimpleAction *action,
                        gpointer       user_data)
 {
   GbTerminalWorkbenchAddin *self = user_data;
+  g_autofree gchar *cwd = NULL;
   GbTerminalView *view;
   IdePerspective *perspective;
   IdeRuntime *runtime = NULL;
@@ -91,7 +92,31 @@ new_terminal_activate (GSimpleAction *action,
   perspective = ide_workbench_get_perspective_by_name (self->workbench, "editor");
   ide_workbench_set_visible_perspective (self->workbench, perspective);
 
+  if (g_strcmp0 (name, "new-terminal-in-dir") == 0)
+    {
+      IdeLayoutView *editor;
+
+      editor = ide_editor_perspective_get_active_view (IDE_EDITOR_PERSPECTIVE (perspective));
+
+      if (IDE_IS_EDITOR_VIEW (editor))
+        {
+          IdeBuffer *buffer;
+
+          buffer = ide_editor_view_get_buffer (IDE_EDITOR_VIEW (editor));
+
+          if (buffer != NULL)
+            {
+              IdeFile *file = ide_buffer_get_file (buffer);
+              GFile *gfile = ide_file_get_file (file);
+              g_autoptr(GFile) parent = g_file_get_parent (gfile);
+
+              cwd = g_file_get_path (parent);
+            }
+        }
+    }
+
   view = g_object_new (GB_TYPE_TERMINAL_VIEW,
+                       "cwd", cwd,
                        "run-on-host", run_on_host,
                        "runtime", runtime,
                        "visible", TRUE,
@@ -181,6 +206,16 @@ failure:
   IDE_EXIT;
 }
 
+static void
+on_run_manager_stopped (GbTerminalWorkbenchAddin *self,
+                        IdeRunManager            *run_manager)
+{
+  g_assert (GB_IS_TERMINAL_WORKBENCH_ADDIN (self));
+  g_assert (IDE_IS_RUN_MANAGER (run_manager));
+
+  gb_terminal_view_feed (self->run_terminal, _("Application exited\r\n"));
+}
+
 static const DzlShortcutEntry gb_terminal_shortcut_entries[] = {
   { "org.gnome.builder.workbench.new-terminal",
     0, NULL,
@@ -236,6 +271,7 @@ gb_terminal_workbench_addin_load (IdeWorkbenchAddin *addin,
   static const GActionEntry actions[] = {
     { "new-terminal", new_terminal_activate },
     { "new-terminal-in-runtime", new_terminal_activate },
+    { "new-terminal-in-dir", new_terminal_activate },
     { "debug-terminal", new_terminal_activate },
   };
 
@@ -281,6 +317,11 @@ gb_terminal_workbench_addin_load (IdeWorkbenchAddin *addin,
                            G_CALLBACK (on_run_manager_run),
                            self,
                            G_CONNECT_SWAPPED);
+  g_signal_connect_object (run_manager,
+                           "stopped",
+                           G_CALLBACK (on_run_manager_stopped),
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 static void
@@ -288,11 +329,24 @@ gb_terminal_workbench_addin_unload (IdeWorkbenchAddin *addin,
                                     IdeWorkbench      *workbench)
 {
   GbTerminalWorkbenchAddin *self = (GbTerminalWorkbenchAddin *)addin;
+  IdeRunManager *run_manager;
+  IdeContext *context;
 
   g_assert (GB_IS_TERMINAL_WORKBENCH_ADDIN (self));
 
   g_action_map_remove_action (G_ACTION_MAP (self->workbench), "new-terminal");
   g_action_map_remove_action (G_ACTION_MAP (self->workbench), "new-terminal-in-runtime");
+  g_action_map_remove_action (G_ACTION_MAP (self->workbench), "new-terminal-in-dir");
+
+  context = ide_workbench_get_context (workbench);
+
+  run_manager = ide_context_get_run_manager (context);
+  g_signal_handlers_disconnect_by_func (run_manager,
+                                        G_CALLBACK (on_run_manager_run),
+                                        self);
+  g_signal_handlers_disconnect_by_func (run_manager,
+                                        G_CALLBACK (on_run_manager_stopped),
+                                        self);
 
   if (self->panel_dock_widget != NULL)
     {
