@@ -101,6 +101,7 @@ populate_state_free (PopulateState *state)
   g_assert (state != NULL);
 
   g_clear_object (&state->self);
+  g_clear_object (&state->completion_context);
   g_clear_object (&state->ifile);
   g_clear_object (&state->buffer);
   g_clear_object (&state->cancellable);
@@ -115,7 +116,7 @@ copy_children (GPtrArray *children)
   g_assert (children != NULL);
 
   copy = g_ptr_array_new ();
-  for (gint i = 0; i < children->len; ++i)
+  for (guint i = 0; i < children->len; ++i)
     g_ptr_array_add (copy, g_ptr_array_index (children, i));
 
   return copy;
@@ -246,7 +247,7 @@ move_candidates (GPtrArray *array,
   if (sub_array->len == 0)
     return;
 
-  for (gint i = 0; i < sub_array->len; ++i)
+  for (guint i = 0; i < sub_array->len; ++i)
     g_ptr_array_add (array, g_ptr_array_index (sub_array, i));
 
   g_ptr_array_remove_range (sub_array, 0, sub_array->len);
@@ -352,7 +353,7 @@ get_matching_candidates (IdeXmlCompletionProvider *self,
   candidates_tmp = g_ptr_array_sized_new (16);
   defines = g_ptr_array_new ();
 
-  for (gint i = 0; i < schemas->len; ++i)
+  for (guint i = 0; i < schemas->len; ++i)
     {
       schema_entry = g_ptr_array_index (schemas, i);
       /* TODO: only RNG for now */
@@ -444,7 +445,7 @@ matching_state_copy (MatchingState *state)
   if (state->children != NULL)
     {
       new_state->children = g_ptr_array_new ();
-      for (gint i = 0; i < state->children->len; ++i)
+      for (guint i = 0; i < state->children->len; ++i)
         g_ptr_array_add (new_state->children, g_ptr_array_index (state->children, i));
     }
 
@@ -483,7 +484,7 @@ create_initial_matching_state (IdeXmlPosition  *position,
   g_assert (IDE_IS_XML_SYMBOL_NODE (pos_node));
 
   nb_nodes = ide_xml_symbol_node_get_n_direct_children (pos_node);
-  for (gint i = 0; i < nb_nodes; ++i)
+  for (guint i = 0; i < nb_nodes; ++i)
     {
       /* Inject a fake node at child_pos */
       if (child_pos == i)
@@ -780,7 +781,7 @@ get__element_proposals (IdeXmlPosition *position,
   if (ide_xml_position_get_kind (position) == IDE_XML_POSITION_KIND_IN_CONTENT)
     start = "<";
 
-  for (gint i = 0; i < items->len; ++i)
+  for (guint i = 0; i < items->len; ++i)
     {
       g_autofree gchar *label = NULL;
       g_autofree gchar *text = NULL;
@@ -811,7 +812,7 @@ get_attributes_proposals (IdeXmlPosition  *position,
   node = ide_xml_position_get_child_node (position);
   if (NULL != (attributes = ide_xml_completion_attributes_get_matches (define, node, TRUE)))
     {
-      for (gint i = 0; i < attributes->len; ++i)
+      for (guint i = 0; i < attributes->len; ++i)
         {
           g_autofree gchar *name = NULL;
           g_autofree gchar *text = NULL;
@@ -878,7 +879,7 @@ get_values_proposals (IdeXmlPosition  *position,
 
           if (NULL != (values = ide_xml_completion_values_get_matches (attr_define, content, detail_value)))
             {
-              for (gint i = 0; i < values->len; ++i)
+              for (guint i = 0; i < values->len; ++i)
                 {
                   ValueMatchItem *value_match_item = g_ptr_array_index (values, i);
 
@@ -902,28 +903,46 @@ populate_cb (GObject      *object,
              gpointer      user_data)
 {
   IdeXmlService *service = (IdeXmlService *)object;
-  PopulateState *state = (PopulateState *)user_data;
-  IdeXmlCompletionProvider *self = state->self;
-  g_autoptr (IdeXmlPosition) position = NULL;
-  IdeXmlSymbolNode *root_node, *node, *candidate_node;
-  IdeXmlAnalysis *analysis;
-  IdeXmlPositionKind kind;
-  IdeXmlPositionDetail detail;
-  g_autoptr (IdeXmlPath) path = NULL;
-  GPtrArray *schemas;
-  g_autoptr (GPtrArray) candidates = NULL;
+  PopulateState *state = user_data;
+  g_autoptr(IdeXmlPosition) position = NULL;
+  g_autoptr(IdeXmlPath) path = NULL;
+  g_autoptr(GPtrArray) candidates = NULL;
+  g_autoptr(GPtrArray) items = NULL;
+  g_autoptr(GError) error = NULL;
+  IdeXmlCompletionProvider *self;
+  IdeXmlSymbolNode *root_node;
+  IdeXmlSymbolNode *node;
+  IdeXmlSymbolNode *candidate_node;
   IdeXmlRngDefine *def;
+  IdeXmlAnalysis *analysis;
   MatchingState *initial_state;
-  g_autoptr (GPtrArray) items = NULL;
-  GError *error = NULL;
-  gint child_pos;
+  GPtrArray *schemas;
+  IdeXmlPositionDetail detail;
+  IdeXmlPositionKind kind;
   gboolean complete_attributes = FALSE;
   gboolean complete_values = FALSE;
+  gboolean did_final_add = FALSE;
+  gint child_pos;
 
-  g_assert (IDE_IS_XML_COMPLETION_PROVIDER (self));
   g_assert (IDE_IS_XML_SERVICE (service));
+  g_assert (state != NULL);
+  g_assert (IDE_IS_XML_COMPLETION_PROVIDER (state->self));
+  g_assert (G_IS_ASYNC_RESULT (result));
+  g_assert (GTK_SOURCE_IS_COMPLETION_CONTEXT (state->completion_context));
+
+  self = state->self;
+
+  /* Check cancellation state first, as that tells us we should
+   * not notify the context of any proposals.
+   */
+  if (g_cancellable_is_cancelled (state->cancellable))
+    goto free_state;
 
   position = ide_xml_service_get_position_from_cursor_finish (service, result, &error);
+
+  if (error != NULL)
+    goto cleanup;
+
   analysis = ide_xml_position_get_analysis (position);
   schemas = ide_xml_analysis_get_schemas (analysis);
   root_node = ide_xml_analysis_get_root_node (analysis);
@@ -932,9 +951,6 @@ populate_cb (GObject      *object,
   detail = ide_xml_position_get_detail (position);
   child_pos = ide_xml_position_get_child_pos (position);
 
-  if (g_cancellable_is_cancelled (state->cancellable))
-    goto cleanup;
-
   if (kind == IDE_XML_POSITION_KIND_IN_START_TAG || kind == IDE_XML_POSITION_KIND_IN_END_TAG)
     {
       if (detail == IDE_XML_POSITION_DETAIL_IN_ATTRIBUTE_NAME)
@@ -962,9 +978,9 @@ populate_cb (GObject      *object,
     {
       if (complete_attributes)
         {
-          for (gint i = 0; i < candidates->len; ++i)
+          for (guint i = 0; i < candidates->len; ++i)
             {
-              g_autoptr (GList) results = NULL;
+              g_autoptr(GList) results = NULL;
 
               def = g_ptr_array_index (candidates, i);
               results = get_attributes_proposals (position, def);
@@ -972,13 +988,14 @@ populate_cb (GObject      *object,
                                                            GTK_SOURCE_COMPLETION_PROVIDER (self),
                                                            results,
                                                            TRUE);
+              did_final_add = TRUE;
             }
         }
       else if (complete_values)
         {
-          for (gint i = 0; i < candidates->len; ++i)
+          for (guint i = 0; i < candidates->len; ++i)
             {
-              g_autoptr (GList) results = NULL;
+              g_autoptr(GList) results = NULL;
 
               def = g_ptr_array_index (candidates, i);
               results = get_values_proposals (position, def);
@@ -986,11 +1003,12 @@ populate_cb (GObject      *object,
                                                            GTK_SOURCE_COMPLETION_PROVIDER (self),
                                                            results,
                                                            TRUE);
+              did_final_add = TRUE;
             }
         }
       else
         {
-          g_autoptr (GList) results = NULL;
+          g_autoptr(GList) results = NULL;
 
           items = g_ptr_array_new_with_free_func ((GDestroyNotify)completion_item_free);
           if (child_pos != -1)
@@ -999,7 +1017,7 @@ populate_cb (GObject      *object,
               ide_xml_position_set_child_node (position, candidate_node);
             }
 
-          for (gint i = 0; i < candidates->len; ++i)
+          for (guint i = 0; i < candidates->len; ++i)
             {
               def = g_ptr_array_index (candidates, i);
 
@@ -1013,10 +1031,17 @@ populate_cb (GObject      *object,
                                                        GTK_SOURCE_COMPLETION_PROVIDER (self),
                                                        results,
                                                        TRUE);
+          did_final_add = TRUE;
         }
     }
 
 cleanup:
+  if (!did_final_add)
+    gtk_source_completion_context_add_proposals (state->completion_context,
+                                                 GTK_SOURCE_COMPLETION_PROVIDER (self),
+                                                 NULL, TRUE);
+
+free_state:
   populate_state_free (state);
 }
 
@@ -1038,12 +1063,11 @@ ide_xml_completion_provider_populate (GtkSourceCompletionProvider *self,
 
   gtk_source_completion_context_get_iter (completion_context, &iter);
 
-  state = g_slice_new0 (PopulateState);
-
   buffer = IDE_BUFFER (gtk_text_iter_get_buffer (&iter));
 
+  state = g_slice_new0 (PopulateState);
   state->self = g_object_ref (IDE_XML_COMPLETION_PROVIDER (self));
-  state->completion_context = completion_context;
+  state->completion_context = g_object_ref (completion_context);
   state->cancellable = g_cancellable_new ();
   state->buffer = g_object_ref (buffer);
   state->ifile = g_object_ref (ide_buffer_get_file (buffer));
